@@ -18,7 +18,7 @@ const char Cart_fileid[] = "Hatari cart.c";
 
 /* 2007/12/09	[NP]	Change the function associated to opcodes $8, $a and $c only if hard drive	*/
 /*			emulation is ON. Else, these opcodes should give illegal instructions (also	*/
-/*			see uae-cpu/newcpu.c).								*/
+/*			see cpu/newcpu.c).								*/
 
 
 #include "main.h"
@@ -52,7 +52,7 @@ static const char * const psCartNameExts[] =
  */
 static void Cart_LoadImage(void)
 {
-	Uint8 *pCartData;
+	uint8_t *pCartData;
 	long nCartSize;
 	char *pCartFileName = ConfigureParams.Rom.szCartridgeImageFileName;
 
@@ -96,9 +96,10 @@ static void Cart_LoadImage(void)
  */
 bool Cart_UseBuiltinCartridge(void)
 {
+#define NEEDS_CART (TRACE_OS_GEMDOS | TRACE_OS_BASE | TRACE_OS_VDI | TRACE_OS_AES)
 	return (bUseVDIRes || INF_Overriding(AUTOSTART_INTERCEPT) ||
 	        ConfigureParams.HardDisk.bUseHardDiskDirectories ||
-	        LogTraceFlags & (TRACE_OS_GEMDOS | TRACE_OS_BASE | TRACE_OS_VDI | TRACE_OS_AES))
+	        LOG_TRACE_LEVEL(NEEDS_CART))
 	       && (TosVersion >= 0x100 || !bUseTos);
 }
 
