@@ -12,13 +12,17 @@
 #include "disasm.h"
 #include "profile.h"
 
-int disasm_flags = DISASM_FLAG_LC_MNEMO | DISASM_FLAG_LC_REG | DISASM_FLAG_LC_SIZE | DISASM_FLAG_LC_HEX | DISASM_FLAG_CC | DISASM_FLAG_EA | DISASM_FLAG_VAL | DISASM_FLAG_WORDS;
+int disasm_flags = DISASM_FLAG_LC_MNEMO | DISASM_FLAG_LC_REG | DISASM_FLAG_LC_SIZE | DISASM_FLAG_LC_HEX |
+	DISASM_FLAG_CC | DISASM_FLAG_EA | DISASM_FLAG_VAL | DISASM_FLAG_WORDS | DISASM_FLAG_ABSSHORTLONG;
 int disasm_min_words = 5;
 int disasm_max_words = 16;
 TCHAR disasm_hexprefix[3] = { '$', 0 };
 
-static TCHAR disasm_areg, disasm_dreg;
+#define LINE_BUF_SIZE 80
+
+static TCHAR disasm_areg, disasm_dreg, disasm_byte, disasm_word, disasm_long;
 static TCHAR disasm_pcreg[3], disasm_fpreg[3];
+static bool absshort_long = false;
 
 void disasm_init(void)
 {
@@ -30,6 +34,10 @@ void disasm_init(void)
 	}
 	disasm_areg = (disasm_flags & DISASM_FLAG_LC_REG) ? 'a' : 'A';
 	disasm_dreg = (disasm_flags & DISASM_FLAG_LC_REG) ? 'd' : 'D';
+	disasm_byte = (disasm_flags & DISASM_FLAG_LC_REG) ? 'b' : 'B';
+	disasm_word = (disasm_flags & DISASM_FLAG_LC_REG) ? 'w' : 'W';
+	disasm_long = (disasm_flags & DISASM_FLAG_LC_REG) ? 'l' : 'L';
+	absshort_long = (disasm_flags & DISASM_FLAG_ABSSHORTLONG) != 0;
 
 }
 
@@ -109,18 +117,18 @@ static const TCHAR *disasm_lc_hex2(const TCHAR *s, bool noprefix)
 			}
 			const TCHAR *s2 = _tcschr(tmp, '%');
 			if (s2) {
-				int len = _tcslen(disasm_hexprefix);
+				int len = uaetcslen(disasm_hexprefix);
 				if (s2 > tmp && s2[-1] == '$') {
 					len--;
 					s2--;
 				}
 				if (len < 0) {
-					memmove(tmp + (s2 - tmp), tmp + (s2 - tmp) - len, (_tcslen(tmp + (s2 - tmp) - len) + 1) * sizeof(TCHAR));
+					memmove(tmp + (s2 - tmp), tmp + (s2 - tmp) - len, (uaetcslen(tmp + (s2 - tmp) - len) + 1) * sizeof(TCHAR));
 				} else {
 					if (len > 0) {
-						memmove(tmp + (s2 - tmp) + len, s2, (_tcslen(s2) + 1) * sizeof(TCHAR));
+						memmove(tmp + (s2 - tmp) + len, s2, (uaetcslen(s2) + 1) * sizeof(TCHAR));
 					}
-					memcpy(tmp + (s2 - tmp), disasm_hexprefix, _tcslen(disasm_hexprefix) * sizeof(TCHAR));
+					memcpy(tmp + (s2 - tmp), disasm_hexprefix, uaetcslen(disasm_hexprefix) * sizeof(TCHAR));
 				}
 			}
 			return tmp;
@@ -210,7 +218,7 @@ static void showea_val(TCHAR *buffer, uae_u16 opcode, uaecptr addr, int size)
 #endif
 #endif
 
-	if (!(disasm_flags & DISASM_FLAG_VAL)) {
+	if (!(disasm_flags & (DISASM_FLAG_VAL_FORCE | DISASM_FLAG_VAL))) {
 		goto skip;
 	}
  
@@ -293,11 +301,13 @@ skip:
 #ifndef WINUAE_FOR_HATARI
 		TCHAR name[256];
 		if (debugmem_get_symbol(addr + i, name, sizeof(name) / sizeof(TCHAR))) {
+			_stprintf(buffer + _tcslen(buffer), _T(" %s"), name);
 #else
 		const char *name;
 		if ((name = Symbols_GetByCpuAddress(addr + i, SYMTYPE_TEXT))) {
+			int len = _tcslen(buffer);
+			snprintf(buffer + len, LINE_BUF_SIZE - len, _T(" %s"), name);
 #endif
-			_stprintf(buffer + _tcslen(buffer), _T(" %s"), name);
 		}
 	}
 }
@@ -347,7 +357,7 @@ uaecptr ShowEA_disp(uaecptr *pcp, uaecptr base, TCHAR *buffer, const TCHAR *name
 				name = NULL;
 		}
 		if (buffer)
-			_stprintf(dr, _T("%c%d.%c"), dp & 0x8000 ? 'A' : 'D', (int)r, dp & 0x800 ? 'L' : 'W');
+			_stprintf(dr, _T("%c%d.%c"), dp & 0x8000 ? disasm_areg : disasm_dreg, (int)r, dp & 0x800 ? disasm_long : disasm_word);
 		if (dp & 0x40) { // IS (index suppress)
 			dispreg = 0;
 			dr[0] = 0;
@@ -452,8 +462,10 @@ uaecptr ShowEA_disp(uaecptr *pcp, uaecptr base, TCHAR *buffer, const TCHAR *name
 		addr = base + outer;
 
 		if (buffer) {
-			_stprintf(p, disasm_lc_hex(_T(" == $%08X")), addr);
-			p += _tcslen(p);
+			if (disasm_flags & (DISASM_FLAG_VAL_FORCE | DISASM_FLAG_VAL)) {
+				_stprintf(p, disasm_lc_hex(_T(" == $%08X")), addr);
+				p += _tcslen(p);
+			}
 		}
 
 	} else {
@@ -469,13 +481,21 @@ uaecptr ShowEA_disp(uaecptr *pcp, uaecptr base, TCHAR *buffer, const TCHAR *name
 			}
 		}
 		regstr[0] = 0;
-		_stprintf(regstr, _T(",%c%d.%c"), dp & 0x8000 ? disasm_areg : disasm_dreg, (int)r, dp & 0x800 ? 'L' : 'W');
+		_stprintf(regstr, _T(",%c%d.%c"), dp & 0x8000 ? disasm_areg : disasm_dreg, (int)r, dp & 0x800 ? disasm_long : disasm_word);
 		addr = base + (uae_s32)((uae_s8)disp8) + dispreg;
 		if (buffer) {
 			if (pcrel) {
-				_stprintf(buffer, _T("(%s%s%s,$%02x=$%08x) == $%08x"), name, regstr, mult, (uae_u8)disp8, (*pcp) += disp8, addr);
+				if (disasm_flags & (DISASM_FLAG_VAL_FORCE | DISASM_FLAG_VAL)) {
+					_stprintf(buffer, _T("(%s%s%s,$%02x=$%08x) == $%08x"), name, regstr, mult, (uae_u8)disp8, (*pcp) += disp8, addr);
+				} else {
+					_stprintf(buffer, _T("(%s%s%s,$%02x=$%08x)"), name, regstr, mult, (uae_u8)disp8, (*pcp) += disp8);
+				}
 			} else {
-				_stprintf(buffer, _T("(%s%s%s,$%02x) == $%08x"), name, regstr, mult, (uae_u8)disp8, addr);
+				if (disasm_flags & (DISASM_FLAG_VAL_FORCE | DISASM_FLAG_VAL)) {
+					_stprintf(buffer, _T("(%s%s%s,$%02x) == $%08x"), name, regstr, mult, (uae_u8)disp8, addr);
+				} else {
+					_stprintf(buffer, _T("(%s%s%s,$%02x)"), name, regstr, mult, (uae_u8)disp8);
+				}
 			}
 			if (((dp & 0x0100) || m != 1) && currprefs.cpu_model < 68020) {
 				_tcscat(buffer, _T(" (68020+)"));
@@ -492,7 +512,7 @@ uaecptr ShowEA(void *f, uaecptr pc, uae_u16 opcode, int reg, amodes mode, wordsi
 	uaecptr addr = pc;
 	uae_s16 disp16;
 	uae_s32 offset = 0;
-	TCHAR buffer[80];
+	TCHAR buffer[LINE_BUF_SIZE];
 
 	if (actualea)
 		*actualea = 1;
@@ -516,16 +536,25 @@ uaecptr ShowEA(void *f, uaecptr pc, uae_u16 opcode, int reg, amodes mode, wordsi
 	case Aind:
 		_stprintf(buffer, _T("(%c%d)"), disasm_areg, reg);
 		addr = regs.regs[reg + 8];
+		if (disasm_flags & DISASM_FLAG_VAL_FORCE) {
+			_stprintf(buffer + _tcslen(buffer), disasm_lc_hex(_T(" == $%08X")), addr);
+		}
 		showea_val(buffer, opcode, addr, size);
 		break;
 	case Aipi:
 		_stprintf(buffer, _T("(%c%d)+"), disasm_areg, reg);
 		addr = regs.regs[reg + 8];
+		if (disasm_flags & DISASM_FLAG_VAL_FORCE) {
+			_stprintf(buffer + _tcslen(buffer), disasm_lc_hex(_T(" == $%08X")), addr);
+		}
 		showea_val(buffer, opcode, addr, size);
 		break;
 	case Apdi:
 		_stprintf(buffer, _T("-(%c%d)"), disasm_areg, reg);
 		addr = regs.regs[reg + 8] - datasizes[size];
+		if (disasm_flags & DISASM_FLAG_VAL_FORCE) {
+			_stprintf(buffer + _tcslen(buffer), disasm_lc_hex(_T(" == $%08X")), addr);
+		}
 		showea_val(buffer, opcode, addr, size);
 		break;
 	case Ad16:
@@ -538,7 +567,7 @@ uaecptr ShowEA(void *f, uaecptr pc, uae_u16 opcode, int reg, amodes mode, wordsi
 				_stprintf (offtxt, disasm_lc_hex(_T("$%04X")), disp16);
 			addr = m68k_areg (regs, reg) + disp16;
 			_stprintf(buffer, _T("(%c%d,%s)"), disasm_areg, reg, offtxt);
-			if (disasm_flags & DISASM_FLAG_VAL) {
+			if (disasm_flags & (DISASM_FLAG_VAL_FORCE | DISASM_FLAG_VAL)) {
 				_stprintf(buffer + _tcslen(buffer), disasm_lc_hex(_T(" == $%08X")), addr);
 			}
 			showea_val(buffer, opcode, addr, size);
@@ -557,7 +586,7 @@ uaecptr ShowEA(void *f, uaecptr pc, uae_u16 opcode, int reg, amodes mode, wordsi
 		addr += (uae_s16)disp16;
 		_stprintf(buffer, _T("(%s"), disasm_pcreg);
 		_stprintf(buffer + _tcslen(buffer), disasm_lc_hex(_T(",$%04X)")), disp16 & 0xffff);
-		if (disasm_flags & DISASM_FLAG_VAL) {
+		if (disasm_flags & (DISASM_FLAG_VAL_FORCE | DISASM_FLAG_VAL)) {
 			_stprintf(buffer + _tcslen(buffer), disasm_lc_hex(_T(" == $%08X")), addr);
 		}
 		showea_val(buffer, opcode, addr, size);
@@ -569,10 +598,19 @@ uaecptr ShowEA(void *f, uaecptr pc, uae_u16 opcode, int reg, amodes mode, wordsi
 		}
 		break;
 	case absw:
-		addr = (uae_s32)(uae_s16)get_iword_debug (pc);
-		_stprintf (buffer, disasm_lc_hex(_T("$%04X")), (uae_u16)addr);
-		pc += 2;
-		showea_val(buffer, opcode, addr, size);
+		{
+			addr = (uae_s32)(uae_s16)get_iword_debug (pc);
+			uae_s16 saddr = (uae_s16)addr;
+			if (absshort_long) {
+				_stprintf(buffer, disasm_lc_hex(_T("$%08X.%c")), addr, disasm_word);
+			} else if (saddr < 0) {
+				_stprintf(buffer, disasm_lc_hex(_T("-$%04X.%c")), -saddr, disasm_word);
+			} else {
+				_stprintf(buffer, disasm_lc_hex(_T("$%04X.%c")), saddr, disasm_word);
+			}
+			pc += 2;
+			showea_val(buffer, opcode, addr, size);
+		}
 		break;
 	case absl:
 		addr = get_ilong_debug (pc);
@@ -1136,7 +1174,6 @@ static int asm_parse_mode(TCHAR *s, uae_u8 *reg, uae_u32 *v, int *extcnt, uae_u1
 				fullext = -1;
 			else
 				fullext = 2;
-			fullext++;
 		}
 	}
 	if (fullext < 0 || fullext == 1)
@@ -1369,7 +1406,7 @@ int m68k_asm(TCHAR *sline, uae_u16 *out, uaecptr pc)
 	int quick = 0;
 	bool immrelpc = false;
 
-	if (_tcslen(sline) > 100)
+	if (uaetcslen(sline) > 100)
 		return -1;
 
 	srcea[0] = dstea[0] = 0;
@@ -1390,7 +1427,7 @@ int m68k_asm(TCHAR *sline, uae_u16 *out, uaecptr pc)
 	}
 	*p = 0;
 
-	to_upper(line, _tcslen(line));
+	to_upper(line, uaetcslen(line));
 
 	p = line;
 	while (*p && *p != ' ')
@@ -1402,7 +1439,7 @@ int m68k_asm(TCHAR *sline, uae_u16 *out, uaecptr pc)
 	}
 	_tcscpy(ins, line);
 	
-	if (_tcslen(ins) == 0)
+	if (uaetcslen(ins) == 0)
 		return 0;
 
 	int size = 1;
@@ -1484,7 +1521,7 @@ int m68k_asm(TCHAR *sline, uae_u16 *out, uaecptr pc)
 	}
 	
 	if (dmode == Areg) {
-		int l = _tcslen(ins);
+		int l = uaetcslen(ins);
 		if (l <= 2)
 			return -1;
 		TCHAR last = ins[l- 1];
@@ -1511,9 +1548,9 @@ int m68k_asm(TCHAR *sline, uae_u16 *out, uaecptr pc)
 	bool fp = ins[0] == 'F';
 	int tsize = size;
 
-	if (ins[_tcslen(ins) - 1] == 'Q' && _tcslen(ins) > 3 && !fp) {
+	if (ins[uaetcslen(ins) - 1] == 'Q' && uaetcslen(ins) > 3 && !fp) {
 		quick = 1;
-		ins[_tcslen(ins) - 1] = 0;
+		ins[uaetcslen(ins) - 1] = 0;
 		if (inssize < 0)
 			tsize = 2;
 	}
@@ -1677,7 +1714,10 @@ static void resolve_if_jmp(TCHAR *s, uae_u32 addr)
 	if (opcode == 0x4ef9) { // JMP x.l
 		TCHAR *p = s + _tcslen(s);
 		uae_u32 addr2 = get_long_debug(addr + 2);
-		_stprintf(p, disasm_lc_hex(_T(" == $%08X ")), addr2);
+		if (disasm_flags & (DISASM_FLAG_VAL_FORCE | DISASM_FLAG_VAL)) {
+			_stprintf(p, disasm_lc_hex(_T(" == $%08X ")), addr2);
+			
+		}
 		showea_val(p + _tcslen(p), opcode, addr2, 4);
 		TCHAR txt[256];
 		bool ext;
@@ -1806,6 +1846,8 @@ static uaecptr disasm_mmu030(uaecptr pc, uae_u16 opcode, uae_u16 extra, struct i
 		case 0x02: // PLOAD R
 			if (mmu_op30_invea(opcode))
 				break;
+			if (!mmu_op30_helper_get_fc(extra, fc))
+				break;
 			_stprintf(instrname, _T("PLOAD%c"), mode == 0 ? 'W' : 'R');
 			disasm_lc_mnemo(instrname);
 			_stprintf(instrname + _tcslen(instrname), _T(" %s,"), fc);
@@ -2031,7 +2073,7 @@ uae_u32 m68k_disasm_2(TCHAR *buf, int bufsize, uaecptr pc, uae_u16 *bufpc, int b
 			_stprintf(p, _T("%c%d:%c%d,%c%d,%c%d,(%c%d):(%c%d)"),
 				disasm_dreg, extra & 7, disasm_dreg, extra2 & 7, disasm_dreg, (extra >> 6) & 7, disasm_dreg, (extra2 >> 6) & 7,
 				(extra & 0x8000) ? disasm_areg : disasm_dreg, (extra >> 12) & 7,
-				(extra2 & 0x8000) ? disasm_dreg : disasm_dreg, (extra2 >> 12) & 7);
+				(extra2 & 0x8000) ? disasm_areg : disasm_dreg, (extra2 >> 12) & 7);
 			add_disasm_word(&pc, &bufpc, &bufpcsize, 4);
 		} else if (lookup->mnemo == i_ORSR || lookup->mnemo == i_ANDSR || lookup->mnemo == i_EORSR) {
 			pc = ShowEA(NULL, pc, opcode, dp->sreg, dp->smode, dp->size, instrname, &seaddr2, &actualea_src, safemode);
@@ -2186,8 +2228,8 @@ uae_u32 m68k_disasm_2(TCHAR *buf, int bufsize, uaecptr pc, uae_u16 *bufpc, int b
 		} else if (lookup->mnemo == i_CALLM) {
 			TCHAR *p = instrname + _tcslen(instrname);
 			_stprintf(p, _T("#%d,"), extra & 255);
-			pc = ShowEA(NULL, pc, opcode, dp->sreg, dp->smode, dp->size, instrname, &seaddr2, &actualea_src, safemode);
 			add_disasm_word(&pc, &bufpc, &bufpcsize, 2);
+			pc = ShowEA(NULL, pc, opcode, dp->sreg, dp->smode, dp->size, instrname, &seaddr2, &actualea_src, safemode);
 		} else if (lookup->mnemo == i_FDBcc) {
 			pc = ShowEA(NULL, pc, opcode, dp->dreg, dp->dmode, dp->size, instrname, &seaddr2, &actualea_src, safemode);
 			add_disasm_word(&pc, &bufpc, &bufpcsize, 2);
@@ -2234,6 +2276,14 @@ uae_u32 m68k_disasm_2(TCHAR *buf, int bufsize, uaecptr pc, uae_u16 *bufpc, int b
 					if (regmask == 1 || regmask == 2 || regmask == 4)
 						_tcscpy(instrname, _T("FMOVE.L "));
 					disasm_lc_mnemo(instrname);
+					int msk = regmask & 2;
+					if (regmask & 1) {
+						msk |= 4;
+					}
+					if (regmask & 4) {
+						msk |= 1;
+					}
+					regmask = msk;
 				}
 				p = instrname + _tcslen(instrname);
 				if (dr) {
@@ -2305,11 +2355,15 @@ uae_u32 m68k_disasm_2(TCHAR *buf, int bufsize, uaecptr pc, uae_u16 *bufpc, int b
 						_stprintf(p, _T(" %s%d"), disasm_fpreg, (extra >> 10) & 7);
 					}
 					p = instrname + _tcslen(instrname);
-					if ((extra & 0x4000) || (((extra >> 7) & 7) != ((extra >> 10) & 7)))
-						_stprintf(p, _T(",%s%d"), disasm_fpreg, (extra >> 7) & 7);
 					if (ins >= 0x30 && ins < 0x38) { // FSINCOS
 						p = instrname + _tcslen(instrname);
 						_stprintf(p, _T(",%s%d"), disasm_fpreg, extra & 7);
+						p = instrname + _tcslen(instrname);
+						_stprintf(p, _T(",%s%d"), disasm_fpreg, (extra >> 7) & 7);
+					} else {
+						if ((extra & 0x4000) || (((extra >> 7) & 7) != ((extra >> 10) & 7))) {
+							_stprintf(p, _T(",%s%d"), disasm_fpreg, (extra >> 7) & 7);
+						}
 					}
 				}
 				if (ins >= 0x40 && currprefs.fpu_model >= 68881 && fpuopcodes[ins]) {
@@ -2352,6 +2406,7 @@ uae_u32 m68k_disasm_2(TCHAR *buf, int bufsize, uaecptr pc, uae_u16 *bufpc, int b
 				if (lookup->mnemo == i_RTS || lookup->mnemo == i_RTD || lookup->mnemo == i_RTR || lookup->mnemo == i_RTE) {
 					uaecptr a = regs.regs[15];
 					TCHAR eas[100];
+					eas[0] = 0;
 					if (lookup->mnemo == i_RTE || lookup->mnemo == i_RTR) {
 						a += 2;
 					}
@@ -2384,20 +2439,28 @@ uae_u32 m68k_disasm_2(TCHAR *buf, int bufsize, uaecptr pc, uae_u16 *bufpc, int b
 				*deaddr = pc;
 			if ((opcode & 0xf000) == 0xf000) {
 				if (currprefs.fpu_model) {
-					buf = buf_out(buf, &bufsize, disasm_lc_hex(_T(" == $%08X")), addr2);
-					if (fpp_cond(dp->cc)) {
-						buf = buf_out(buf, &bufsize, _T(" (T)"));
-					} else {
-						buf = buf_out(buf, &bufsize, _T(" (F)"));
+					if (disasm_flags & DISASM_FLAG_EA) {
+						buf = buf_out(buf, &bufsize, disasm_lc_hex(_T(" == $%08X")), addr2);
+					}
+					if (disasm_flags & DISASM_FLAG_CC) {
+						if (fpp_cond(dp->cc)) {
+							buf = buf_out(buf, &bufsize, _T(" (T)"));
+						} else {
+							buf = buf_out(buf, &bufsize, _T(" (F)"));
+						}
 					}
 				}
 			} else {
 				if (dp->mnemo == i_Bcc || dp->mnemo == i_DBcc) {
-					buf = buf_out(buf, &bufsize, disasm_lc_hex(_T(" == $%08X")), addr2);
-					if (cctrue(dp->cc)) {
-						buf = buf_out(buf, &bufsize, _T(" (T)"));
-					} else {
-						buf = buf_out(buf, &bufsize, _T(" (F)"));
+					if (disasm_flags & DISASM_FLAG_EA) {
+						buf = buf_out(buf, &bufsize, disasm_lc_hex(_T(" == $%08X")), addr2);
+					}
+					if (disasm_flags & DISASM_FLAG_CC) {
+						if (cctrue(dp->cc)) {
+							buf = buf_out(buf, &bufsize, _T(" (T)"));
+						} else {
+							buf = buf_out(buf, &bufsize, _T(" (F)"));
+						}
 					}
 				} else {
 					if (disasm_flags & DISASM_FLAG_CC) {
@@ -2440,12 +2503,12 @@ uae_u32 m68k_disasm_2(TCHAR *buf, int bufsize, uaecptr pc, uae_u16 *bufpc, int b
 			TCHAR segout[256];
 			if (debugmem_get_symbol(segpc, segout, sizeof(segout) / sizeof(TCHAR))) {
 				_tcscat(segout, _T(":\n"));
-				if (bufsize > _tcslen(segout)) {
-					memmove(symbolpos + _tcslen(segout), symbolpos, (_tcslen(symbolpos) + 1) * sizeof(TCHAR));
-					memcpy(symbolpos, segout, _tcslen(segout) * sizeof(TCHAR));
-					bufsize -= _tcslen(segout);
-					buf += _tcslen(segout);
-					symbolpos += _tcslen(segout);
+				if (bufsize > uaetcslen(segout)) {
+					memmove(symbolpos + uaetcslen(segout), symbolpos, (uaetcslen(symbolpos) + 1) * sizeof(TCHAR));
+					memcpy(symbolpos, segout, uaetcslen(segout) * sizeof(TCHAR));
+					bufsize -= uaetcslen(segout);
+					buf += uaetcslen(segout);
+					symbolpos += uaetcslen(segout);
 				}
 			}
 		}
