@@ -19,12 +19,17 @@
 
 #define DRIVESOUND
 #define GFXFILTER
+#if defined(_M_ARM64) || defined(_M_ARM64EC)
+#define __arm__
+#define MSVC_LONG_DOUBLE
+#else
 #define X86_MSVC_ASSEMBLY
 //#define OPTIMIZED_FLAGS
 #define MSVC_LONG_DOUBLE
 #ifndef __i386__
 #define __i386__
 #endif
+#endif
 #define WINDOWS
 #define ZLIB_WINAPI
 #define PACKAGE_STRING "WinUAE"
@@ -34,12 +39,16 @@
 
 #ifndef UAE_MINI
 
+#if !defined(_M_ARM64) && !defined(_M_ARM64EC) && !defined(__aarch64__)
+//#define JIT /* JIT compiler support */
+//#define USE_JIT_FPU
+#endif
+
 #define DEBUGGER
+//#define GDBSERVER
 #define FILESYS /* filesys emulation */
 #define UAE_FILESYS_THREADS
 //#define AUTOCONFIG /* autoconfig support, fast ram, harddrives etc.. */
-//#define JIT /* JIT compiler support */
-//#define USE_JIT_FPU
 //#define NOFLAGS_SUPPORT_GENCPU
 #define NOFLAGS_SUPPORT_GENCOMP
 //#define HAVE_GET_WORD_UNSWAPPED
@@ -118,6 +127,7 @@
 #define WITH_X86
 #define WITH_THREADED_CPU
 #endif /* ! WINUAE_FOR_HATARI */
+#define WITH_SOFTFLOAT
 
 #else
 
@@ -463,7 +473,7 @@ typedef long uae_atomic;
 /* #undef HAVE_DEVICES_AHI_H */
 
 /* Define if you have the <dirent.h> header file.  */
-/* #define HAVE_DIRENT_H 1 */
+#define HAVE_DIRENT_H 1
 
 /* Define if you have the <fcntl.h> header file.  */
 #ifndef _WIN32_WCE
