@@ -1,7 +1,7 @@
 /*
   Hatari - breakcond.c
 
-  Copyright (c) 2009-2016 by Eero Tamminen
+  Copyright (c) 2009-2024 by Eero Tamminen
 
   This file is distributed under the GNU General Public License, version 2
   or at your option any later version. Read the file gpl.txt for details.
@@ -41,7 +41,7 @@ const char BreakCond_fileid[] = "Hatari breakcond.c";
 #define DEBUG 0
 
 /* needs to go through long long to handle x=32 */
-#define BITMASK(x)      ((Uint32)(((unsigned long long)1<<(x))-1))
+#define BITMASK(x)      ((uint32_t)(((unsigned long long)1<<(x))-1))
 
 #define BC_DEFAULT_DSP_SPACE 'P'
 
@@ -50,14 +50,14 @@ typedef struct {
 	char dsp_space;	/* DSP has P, X, Y address spaces, zero if not DSP */
 	value_t valuetype;	/* Hatari value variable type */
 	union {
-		Uint32 number;
-		Uint16 (*func16)(void);
-		Uint32 (*func32)(void);
-		Uint16 *reg16;
-		Uint32 *reg32;
+		uint32_t number;
+		uint16_t (*func16)(void);
+		uint32_t (*func32)(void);
+		uint16_t *reg16;
+		uint32_t *reg32;
 	} value;
-	Uint32 bits;	/* CPU has 8/16/32 bit address widths */
-	Uint32 mask;	/* <width mask> && <value mask> */
+	uint32_t bits;	/* CPU has 8/16/32 bit address widths */
+	uint32_t mask;	/* <width mask> && <value mask> */
 } bc_value_t;
 
 typedef struct {
@@ -72,7 +72,7 @@ typedef struct {
 	char *filename;	/* file where to read commands to do on hit */
 	int skip;	/* how many times to hit before breaking */
 	bool once;	/* remove after hit&break */
-	bool quiet;	/* no output from setting & hitting */
+	bool quiet;	/* set / hit breakpoint quietly */
 	bool trace;	/* trace mode, don't break */
 	bool noinit;	/* prevent debugger inits on break */
 	bool lock;	/* tracing + show locked info */
@@ -175,7 +175,7 @@ static void _spaces(void)
 /**
  * Return value from given DSP memory space/address
  */
-static Uint32 BreakCond_ReadDspMemory(Uint32 addr, const bc_value_t *bc_value)
+static uint32_t BreakCond_ReadDspMemory(uint32_t addr, const bc_value_t *bc_value)
 {
 	const char *dummy;
 	return DSP_ReadMemory(addr, bc_value->dsp_space, &dummy) & BITMASK(24);
@@ -184,7 +184,7 @@ static Uint32 BreakCond_ReadDspMemory(Uint32 addr, const bc_value_t *bc_value)
 /**
  * Return value of given size read from given ST memory address
  */
-static Uint32 BreakCond_ReadSTMemory(Uint32 addr, const bc_value_t *bc_value)
+static uint32_t BreakCond_ReadSTMemory(uint32_t addr, const bc_value_t *bc_value)
 {
 	switch (bc_value->bits) {
 	case 32:
@@ -201,11 +201,11 @@ static Uint32 BreakCond_ReadSTMemory(Uint32 addr, const bc_value_t *bc_value)
 
 
 /**
- * Return Uint32 value according to given bc_value_t specification
+ * Return uint32_t value according to given bc_value_t specification
  */
-static Uint32 BreakCond_GetValue(const bc_value_t *bc_value)
+static uint32_t BreakCond_GetValue(const bc_value_t *bc_value)
 {
-	Uint32 value;
+	uint32_t value;
 
 	switch (bc_value->valuetype) {
 	case VALUE_TYPE_NUMBER:
@@ -239,9 +239,9 @@ static Uint32 BreakCond_GetValue(const bc_value_t *bc_value)
 /**
  * Show & update rvalue for a tracked breakpoint condition to lvalue
  */
-static void BreakCond_UpdateTracked(bc_condition_t *condition, Uint32 value)
+static void BreakCond_UpdateTracked(bc_condition_t *condition, uint32_t value)
 {
-	Uint32 addr;
+	uint32_t addr;
 
 	/* next monitor changes to this new value */
 	condition->rvalue.value.number = value;
@@ -263,7 +263,7 @@ static void BreakCond_UpdateTracked(bc_condition_t *condition, Uint32 value)
  */
 static bool BreakCond_MatchConditions(bc_condition_t *condition, int count)
 {
-	Uint32 lvalue, rvalue;
+	uint32_t lvalue, rvalue;
 	bool hit = false;
 	int i;
 
@@ -350,7 +350,8 @@ static bool BreakCond_MatchBreakPoints(bc_breakpoints_t *bps)
 					DebugInfo_ShowSessionInfo();
 				}
 				if (bp->options.filename) {
-					DebugUI_ParseFile(bp->options.filename, reinit);
+					bool verbose = !bp->options.quiet;
+					DebugUI_ParseFile(bp->options.filename, reinit, verbose);
 					changes = true;
 				}
 			}
@@ -448,7 +449,7 @@ static bool BreakCond_ParseVariable(const char *name, bc_value_t *bc_value)
 static bool BreakCond_ParseSymbol(const char *name, bc_value_t *bc_value)
 {
 	symtype_t symtype;
-	Uint32 addr;
+	uint32_t addr;
 
 	ENTERFUNC(("BreakCond_ParseSymbol('%s')\n", name));
 	if (bc_value->is_indirect) {
@@ -490,16 +491,16 @@ static bool BreakCond_ParseSymbol(const char *name, bc_value_t *bc_value)
 
 
 /**
- * Helper function to get CPU PC register value with static inline as Uint32
+ * Helper function to get CPU PC register value with static inline as uint32_t
  */
-static Uint32 GetCpuPC(void)
+static uint32_t GetCpuPC(void)
 {
 	return M68000_GetPC();
 }
 /**
- * Helper function to get CPU SR register value with static inline as Uint32
+ * Helper function to get CPU SR register value with static inline as uint32_t
  */
-static Uint32 GetCpuSR(void)
+static uint32_t GetCpuSR(void)
 {
 	return M68000_GetSR();
 }
@@ -566,7 +567,7 @@ static bool BreakCond_ParseRegister(const char *regname, bc_value_t *bc_value)
  */
 static bool BreakCond_CheckAddress(bc_value_t *bc_value)
 {
-	Uint32 addr = bc_value->value.number;
+	uint32_t addr = bc_value->value.number;
 	int size = bc_value->bits >> 8;
 
 	ENTERFUNC(("BreakCond_CheckAddress(%x)\n", addr));
@@ -825,7 +826,7 @@ static char BreakCond_ParseComparison(parser_state_t *pstate)
 /**
  * If no value, use the other value, if that also missing, use default
  */
-static void BreakCond_InheritDefault(Uint32 *value1, Uint32 value2, Uint32 defvalue)
+static void BreakCond_InheritDefault(uint32_t *value1, uint32_t value2, uint32_t defvalue)
 {
 	if (!*value1) {
 		if (value2) {
@@ -845,7 +846,7 @@ static bool BreakCond_CrossCheckValues(parser_state_t *pstate,
 				       bc_value_t *bc_value1,
 				       bc_value_t *bc_value2)
 {
-	Uint32 mask1, mask2, defbits;
+	uint32_t mask1, mask2, defbits;
 	ENTERFUNC(("BreakCond_CrossCheckValues()\n"));
 
 	/* make sure there're valid bit widths and that masks have some value */
@@ -1141,7 +1142,7 @@ static void BreakCond_CheckTracking(bc_breakpoint_t *bp)
 {
 	bc_condition_t *condition;
 	bool track = false;
-	Uint32 value;
+	uint32_t value;
 	int i;
 
 	condition = bp->conditions;
@@ -1477,7 +1478,7 @@ const char BreakCond_Description[] =
 	"\t- 'noinit', no debugger inits on hit, useful for stack tracing\n"
 	"\t- 'file <file>', execute debugger commands from given <file>\n"
 	"\t- 'once', delete the breakpoint after it's hit\n"
-	"\t- 'quiet', no output from setting & hitting breakpoint\n"
+	"\t- 'quiet', set / hit breakpoint quietly\n"
 	"\t- '<count>', break only on every <count> hit";
 
 /**
@@ -1498,10 +1499,12 @@ static bool BreakCond_Options(char *str, bc_options_t *options, char marker)
 	}
 	for (next = option; option; option = next) {
 
+		char splitter[3] = {' ', marker, '\0'};
 		/* skip marker + end & trim this option */
 		option = next + 1;
-		next = strchr(option, marker);
+		next = strstr(option, splitter);
 		if (next) {
+			next++; /* skip space to next marker */
 			*next = 0;
 		}
 		option = Str_Trim(option);
@@ -1622,7 +1625,7 @@ const char BreakAddr_Description[] =
 	"\t- 'trace', print the breakpoint match without stopping\n"
 	"\t- 'lock', print the debugger entry info without stopping\n"
 	"\t- 'once', delete the breakpoint after it's hit\n"
-	"\t- 'quiet', no output from setting & hitting breakpoint\n"
+	"\t- 'quiet', set / hit breakpoint quietly\n"
 	"\t- '<count>', break only on every <count> hit\n"
 	"\n"
 	"\tUse conditional breakpoint commands to manage the created\n"
@@ -1637,7 +1640,7 @@ bool BreakAddr_Command(char *args, bool bForDsp)
 {
 	const char *errstr, *expression = (const char *)args;
 	char *cut, command[32];
-	Uint32 addr;
+	uint32_t addr;
 	int offset;
 
 	if (!args) {
