@@ -16,9 +16,9 @@ extern void DebugDsp_SetDebugging(void);
 #define DebugDsp_SetDebugging()
 #endif /* !ENABLE_DSP_EMU */
 extern void DebugDsp_Check(void);
-extern Uint32 DebugDsp_CallDepth(void);
-extern Uint32 DebugDsp_InstrCount(void);
-extern Uint32 DebugDsp_OpcodeType(void);
+extern uint32_t DebugDsp_CallDepth(void);
+extern uint32_t DebugDsp_InstrCount(void);
+extern uint32_t DebugDsp_OpcodeType(void);
 extern int DebugDsp_DisAsm(int nArgc, char *psArgs[]);
 extern int DebugDsp_MemDump(int nArgc, char *psArgs[]);
 extern int DebugDsp_Register(int nArgc, char *psArgs[]);
