@@ -27,20 +27,23 @@ extern char *Profile_Match(const char *text, int state);
 extern int Profile_Command(int nArgc, char *psArgs[], bool bForDsp);
 
 /* CPU profile control */
+extern void Profile_CpuFree(void);
 extern bool Profile_CpuStart(void);
 extern void Profile_CpuUpdate(void);
 extern void Profile_CpuStop(void);
 
 /* CPU profile results */
-extern bool Profile_CpuAddr_HasData(Uint32 addr);
-extern int Profile_CpuAddr_DataStr(char *buffer, int maxlen, Uint32 addr);
+extern bool Profile_CpuAddr_HasData(uint32_t addr);
+extern int Profile_CpuAddr_DataStr(char *buffer, int maxlen, uint32_t addr);
 
 /* DSP profile control */
+extern void Profile_DspFree(void);
 extern bool Profile_DspStart(void);
 extern void Profile_DspUpdate(void);
 extern void Profile_DspStop(void);
 
 /* DSP profile results */
-extern bool Profile_DspAddressData(Uint16 addr, float *percentage, Uint64 *count, Uint64 *cycles, Uint16 *cycle_diff);
+extern bool Profile_DspAddressData(uint16_t addr, float *percentage, uint64_t *count,
+                                   uint64_t *cycles, uint16_t *cycle_diff);
 
 #endif
