@@ -23,7 +23,6 @@ const char Profiledsp_fileid[] = "Hatari profiledsp.c";
 #include "profile_priv.h"
 #include "debug_priv.h"
 /* for VBL info */
-#include "screen.h"
 #include "video.h"
 
 static callinfo_t dsp_callinfo;
@@ -32,21 +31,21 @@ static callinfo_t dsp_callinfo;
 #define MAX_DSP_PROFILE_VALUE 0xFFFFFFFFFFFFFFFFLL
 
 typedef struct {
-	Uint64 count;		/* how many times this address is used */
-	Uint64 cycles;		/* how many DSP cycles was taken at this address */
-	Uint16 min_cycle;
-	Uint16 max_cycle;
+	uint64_t count;		/* how many times this address is used */
+	uint64_t cycles;		/* how many DSP cycles was taken at this address */
+	uint16_t min_cycle;
+	uint16_t max_cycle;
 } dsp_profile_item_t;
 
 static struct {
 	dsp_profile_item_t *data; /* profile data */
 	profile_area_t ram;   /* statistics for whole memory */
-	Uint16 *sort_arr;     /* data indexes used for sorting */
-	Uint16 prev_pc;       /* previous PC for which the cycles are for */
-	Uint16 loop_start;    /* address of last loop start */
-	Uint16 loop_end;      /* address of last loop end */
-	Uint32 loop_count;    /* how many times it was looped */
-	Uint32 disasm_addr;   /* 'dspaddresses' command start address */
+	uint16_t *sort_arr;     /* data indexes used for sorting */
+	uint16_t prev_pc;       /* previous PC for which the cycles are for */
+	uint16_t loop_start;    /* address of last loop start */
+	uint16_t loop_end;      /* address of last loop end */
+	uint32_t loop_count;    /* how many times it was looped */
+	uint32_t disasm_addr;   /* 'dspaddresses' command start address */
 	bool processed;	      /* true when data is already processed */
 	bool enabled;         /* true when profiling enabled */
 } dsp_profile;
@@ -58,7 +57,8 @@ static struct {
  * Get DSP cycles, count and count percentage for given address.
  * Return true if data was available and non-zero, false otherwise.
  */
-bool Profile_DspAddressData(Uint16 addr, float *percentage, Uint64 *count, Uint64 *cycles, Uint16 *cycle_diff)
+bool Profile_DspAddressData(uint16_t addr, float *percentage, uint64_t *count,
+                            uint64_t *cycles, uint16_t *cycle_diff)
 {
 	dsp_profile_item_t *item;
 	if (!dsp_profile.data) {
@@ -118,12 +118,12 @@ void Profile_DspShowStats(void)
  * Show DSP instructions which execution was profiled, in the address order,
  * starting from the given address.  Return next disassembly address.
  */
-Uint16 Profile_DspShowAddresses(Uint32 addr, Uint32 upper, FILE *out, paging_t use_paging)
+uint16_t Profile_DspShowAddresses(uint32_t addr, uint32_t upper, FILE *out, paging_t use_paging)
 {
 	int show, shown, addrs, active;
 	dsp_profile_item_t *data;
-	Uint16 nextpc;
-	Uint32 end;
+	uint16_t nextpc;
+	uint32_t end;
 	const char *symbol;
 
 	data = dsp_profile.data;
@@ -159,7 +159,7 @@ Uint16 Profile_DspShowAddresses(Uint32 addr, Uint32 upper, FILE *out, paging_t u
 			fputs("[...]\n", out);
 			shown++;
 		}
-		symbol = Symbols_GetByDspAddress(addr, SYMTYPE_TEXT);
+		symbol = Symbols_GetByDspAddress(addr, SYMTYPE_CODE);
 		if (symbol) {
 			fprintf(out, "%s:\n", symbol);
 			shown++;
@@ -168,10 +168,13 @@ Uint16 Profile_DspShowAddresses(Uint32 addr, Uint32 upper, FILE *out, paging_t u
 		addrs++;
 		shown++;
 	}
+	/* use stderr for debugger feedback like elsewhere */
 	if (addr < end) {
-		printf("Disassembled %d (of active %d) DSP addresses.\n", addrs, active);
+		fprintf(stderr, "Disassembled %d (of active %d) DSP addresses.\n",
+			addrs, active);
 	} else {
-		printf("Disassembled last %d (of active %d) DSP addresses, wrapping...\n", addrs, active);
+		fprintf(stderr, "Disassembled last %d (of active %d) DSP addresses, wrapping...\n",
+			addrs, active);
 		nextpc = 0;
 	}
 	return nextpc;
@@ -183,8 +186,8 @@ Uint16 Profile_DspShowAddresses(Uint32 addr, Uint32 upper, FILE *out, paging_t u
  */
 static int cmp_dsp_cycles(const void *p1, const void *p2)
 {
-	Uint64 count1 = dsp_profile.data[*(const Uint16*)p1].cycles;
-	Uint64 count2 = dsp_profile.data[*(const Uint16*)p2].cycles;
+	uint64_t count1 = dsp_profile.data[*(const uint16_t*)p1].cycles;
+	uint64_t count2 = dsp_profile.data[*(const uint16_t*)p2].cycles;
 	if (count1 > count2) {
 		return -1;
 	}
@@ -200,10 +203,10 @@ static int cmp_dsp_cycles(const void *p1, const void *p2)
 void Profile_DspShowCycles(int show)
 {
 	int active;
-	Uint16 *sort_arr, *end, addr;
+	uint16_t *sort_arr, *end, addr;
 	dsp_profile_item_t *data = dsp_profile.data;
 	float percentage;
-	Uint64 count;
+	uint64_t count;
 
 	if (!data) {
 		fprintf(stderr, "ERROR: no DSP profiling data available!\n");
@@ -214,16 +217,16 @@ void Profile_DspShowCycles(int show)
 	sort_arr = dsp_profile.sort_arr;
 	qsort(sort_arr, active, sizeof(*sort_arr), cmp_dsp_cycles);
 
-	printf("addr:\tcycles:\n");
+	fprintf(stderr, "addr:\tcycles:\n");
 	show = (show < active ? show : active);
 	for (end = sort_arr + show; sort_arr < end; sort_arr++) {
 		addr = *sort_arr;
 		count = data[addr].cycles;
 		percentage = 100.0*count/dsp_profile.ram.counters.cycles;
-		printf("0x%04x\t%5.2f%%\t%"PRIu64"%s\n", addr, percentage, count,
+		fprintf(stderr, "0x%04x\t%5.2f%%\t%"PRIu64"%s\n", addr, percentage, count,
 		       count == MAX_DSP_PROFILE_VALUE ? " (OVERFLOW)" : "");
 	}
-	printf("%d DSP addresses listed.\n", show);
+	fprintf(stderr, "%d DSP addresses listed.\n", show);
 }
 
 
@@ -233,8 +236,8 @@ void Profile_DspShowCycles(int show)
  */
 static int cmp_dsp_count(const void *p1, const void *p2)
 {
-	Uint64 count1 = dsp_profile.data[*(const Uint16*)p1].count;
-	Uint64 count2 = dsp_profile.data[*(const Uint16*)p2].count;
+	uint64_t count1 = dsp_profile.data[*(const uint16_t*)p1].count;
+	uint64_t count2 = dsp_profile.data[*(const uint16_t*)p2].count;
 	if (count1 > count2) {
 		return -1;
 	}
@@ -253,10 +256,10 @@ void Profile_DspShowCounts(int show, bool only_symbols)
 {
 	dsp_profile_item_t *data = dsp_profile.data;
 	int symbols, matched, active;
-	Uint16 *sort_arr, *end, addr;
+	uint16_t *sort_arr, *end, addr;
 	const char *name;
 	float percentage;
-	Uint64 count;
+	uint64_t count;
 
 	if (!data) {
 		fprintf(stderr, "ERROR: no DSP profiling data available!\n");
@@ -269,16 +272,16 @@ void Profile_DspShowCounts(int show, bool only_symbols)
 	qsort(sort_arr, active, sizeof(*sort_arr), cmp_dsp_count);
 
 	if (!only_symbols) {
-		printf("addr:\tcount:\n");
+		fprintf(stderr, "addr:\tcount:\n");
 		for (end = sort_arr + show; sort_arr < end; sort_arr++) {
 			addr = *sort_arr;
 			count = data[addr].count;
 			percentage = 100.0*count/dsp_profile.ram.counters.count;
-			printf("0x%04x\t%5.2f%%\t%"PRIu64"%s\n",
+			fprintf(stderr, "0x%04x\t%5.2f%%\t%"PRIu64"%s\n",
 			       addr, percentage, count,
 			       count == MAX_DSP_PROFILE_VALUE ? " (OVERFLOW)" : "");
 		}
-		printf("%d DSP addresses listed.\n", show);
+		fprintf(stderr, "%d DSP addresses listed.\n", show);
 		return;
 	}
 
@@ -287,19 +290,19 @@ void Profile_DspShowCounts(int show, bool only_symbols)
 		fprintf(stderr, "ERROR: no DSP symbols loaded!\n");
 		return;
 	}
-	matched = 0;	
+	matched = 0;
 
-	printf("addr:\tcount:\t\tsymbol:\n");
+	fprintf(stderr, "addr:\tcount:\t\tsymbol:\n");
 	for (end = sort_arr + active; sort_arr < end; sort_arr++) {
 
 		addr = *sort_arr;
-		name = Symbols_GetByDspAddress(addr, SYMTYPE_TEXT);
+		name = Symbols_GetByDspAddress(addr, SYMTYPE_CODE);
 		if (!name) {
 			continue;
 		}
 		count = data[addr].count;
 		percentage = 100.0*count/dsp_profile.ram.counters.count;
-		printf("0x%04x\t%.2f%%\t%"PRIu64"\t%s%s\n",
+		fprintf(stderr, "0x%04x\t%.2f%%\t%"PRIu64"\t%s%s\n",
 		       addr, percentage, count, name,
 		       count == MAX_DSP_PROFILE_VALUE ? " (OVERFLOW)" : "");
 
@@ -308,14 +311,14 @@ void Profile_DspShowCounts(int show, bool only_symbols)
 			break;
 		}
 	}
-	printf("%d DSP symbols listed.\n", matched);
+	fprintf(stderr, "%d DSP symbols listed.\n", matched);
 }
 
 
-static const char * addr2name(Uint32 addr, Uint64 *total)
+static const char * addr2name(uint32_t addr, uint64_t *total)
 {
 	*total = dsp_profile.data[addr].count;
-	return Symbols_GetByDspAddress(addr, SYMTYPE_TEXT);
+	return Symbols_GetByDspAddress(addr, SYMTYPE_CODE);
 }
 
 /**
@@ -346,6 +349,23 @@ void Profile_DspSave(FILE *out)
 
 /* ------------------ DSP profile control ----------------- */
 
+/**
+ * Free data from last profiling run, if any
+ */
+void Profile_DspFree(void)
+{
+	Profile_FreeCallinfo(&(dsp_callinfo));
+	if (dsp_profile.sort_arr) {
+		free(dsp_profile.sort_arr);
+		dsp_profile.sort_arr = NULL;
+	}
+	if (dsp_profile.data) {
+		free(dsp_profile.data);
+		dsp_profile.data = NULL;
+		fprintf(stderr, "Freed previous DSP profile buffers.\n");
+	}
+}
+
 /**
  * Initialize DSP profiling when necessary.  Return true if profiling.
  */
@@ -354,15 +374,7 @@ bool Profile_DspStart(void)
 	dsp_profile_item_t *item;
 	int i;
 
-	Profile_FreeCallinfo(&(dsp_callinfo));
-	if (dsp_profile.sort_arr) {
-		/* remove previous results */
-		free(dsp_profile.sort_arr);
-		free(dsp_profile.data);
-		dsp_profile.sort_arr = NULL;
-		dsp_profile.data = NULL;
-		printf("Freed previous DSP profile buffers.\n");
-	}
+	Profile_DspFree();
 	if (!dsp_profile.enabled) {
 		return false;
 	}
@@ -374,7 +386,7 @@ bool Profile_DspStart(void)
 		perror("ERROR, new DSP profile buffer alloc failed");
 		return false;
 	}
-	printf("Allocated DSP profile buffer (%d KB).\n",
+	fprintf(stderr, "Allocated DSP profile buffer (%d KB).\n",
 	       (int)sizeof(*dsp_profile.data)*DSP_PROFILE_ARR_SIZE/1024);
 
 	Profile_AllocCallinfo(&(dsp_callinfo), Symbols_DspCodeCount(), "DSP");
@@ -397,7 +409,7 @@ bool Profile_DspStart(void)
 }
 
 /* return true if pc is next instruction for previous pc */
-static bool is_prev_instr(Uint16 prev_pc, Uint16 pc)
+static bool is_prev_instr(uint16_t prev_pc, uint16_t pc)
 {
 	/* just moved to next instruction (1-2 words)? */
 	if (prev_pc < pc && (pc - prev_pc) <= 4) {
@@ -407,10 +419,10 @@ static bool is_prev_instr(Uint16 prev_pc, Uint16 pc)
 }
 
 /* return branch type based on caller instruction type */
-static calltype_t dsp_opcode_type(Uint16 prev_pc, Uint16 pc)
+static calltype_t dsp_opcode_type(uint16_t prev_pc, uint16_t pc)
 {
 	const char *dummy;
-	Uint32 opcode;
+	uint32_t opcode;
 
 	/* 24-bit instruction opcode */
 	opcode = DSP_ReadMemory(prev_pc, 'P', &dummy) & 0xFFFFFF;
@@ -502,11 +514,11 @@ static calltype_t dsp_opcode_type(Uint16 prev_pc, Uint16 pc)
  * instruction, that's why "pc" argument for this function actually
  * needs to be previous PC.
  */
-static void collect_calls(Uint16 pc, counters_t *counters)
+static void collect_calls(uint16_t pc, counters_t *counters)
 {
 	calltype_t flag;
-	Uint16 prev_pc;
-	Uint32 caller_pc;
+	uint16_t prev_pc;
+	uint32_t caller_pc;
 	int idx;
 
 	prev_pc = dsp_callinfo.prev_pc;
@@ -569,7 +581,7 @@ static void log_last_loop(void)
 void Profile_DspUpdate(void)
 {
 	dsp_profile_item_t *prev;
-	Uint16 pc, prev_pc, cycles;
+	uint16_t pc, prev_pc, cycles;
 	counters_t *counters;
 
 	prev_pc = dsp_profile.prev_pc;
@@ -628,11 +640,11 @@ void Profile_DspUpdate(void)
 /**
  * Helper for collecting DSP profile area statistics.
  */
-static void update_area_item(profile_area_t *area, Uint16 addr, dsp_profile_item_t *item)
+static void update_area_item(profile_area_t *area, uint16_t addr, dsp_profile_item_t *item)
 {
-	Uint64 cycles = item->cycles;
-	Uint64 count = item->count;
-	Uint16 diff;
+	uint64_t cycles = item->cycles;
+	uint64_t count = item->count;
+	uint16_t diff;
 
 	if (!count) {
 		return;
@@ -666,8 +678,8 @@ void Profile_DspStop(void)
 {
 	dsp_profile_item_t *item;
 	profile_area_t *area;
-	Uint16 *sort_arr;
-	Uint32 addr;
+	uint16_t *sort_arr;
+	uint32_t addr;
 
 	if (dsp_profile.processed || !dsp_profile.enabled) {
 		return;
@@ -703,7 +715,7 @@ void Profile_DspStop(void)
 		dsp_profile.data = NULL;
 		return;
 	}
-	printf("Allocated DSP profile address buffer (%d KB).\n",
+	fprintf(stderr, "Allocated DSP profile address buffer (%d KB).\n",
 	       (int)sizeof(*sort_arr)*(dsp_profile.ram.active+512)/1024);
 	dsp_profile.sort_arr = sort_arr;
 
@@ -725,7 +737,7 @@ void Profile_DspStop(void)
  * Get pointers to DSP profile enabling and disasm address variables
  * for updating them (in parser).
  */
-void Profile_DspGetPointers(bool **enabled, Uint32 **disasm_addr)
+void Profile_DspGetPointers(bool **enabled, uint32_t **disasm_addr)
 {
 	*disasm_addr = &dsp_profile.disasm_addr;
 	*enabled = &dsp_profile.enabled;
@@ -734,8 +746,8 @@ void Profile_DspGetPointers(bool **enabled, Uint32 **disasm_addr)
 /**
  * Get callinfo & symbol search pointers for stack walking.
  */
-void Profile_DspGetCallinfo(callinfo_t **callinfo, const char* (**get_caller)(Uint32*),
-			    const char* (**get_symbol)(Uint32, symtype_t))
+void Profile_DspGetCallinfo(callinfo_t **callinfo, const char* (**get_caller)(uint32_t*),
+			    const char* (**get_symbol)(uint32_t, symtype_t))
 {
 	*callinfo = &(dsp_callinfo);
 	*get_caller = Symbols_GetBeforeDspAddress;
