@@ -9,13 +9,23 @@
 #define HATARI_SYMBOLS_H
 
 typedef enum {
-	SYMTYPE_TEXT = 1,  /* Needs to be smallest number for sorting! */
-	SYMTYPE_DATA = 2,
-	SYMTYPE_BSS  = 4,
-	SYMTYPE_ABS  = 8,
-	SYMTYPE_ALL  = SYMTYPE_TEXT|SYMTYPE_DATA|SYMTYPE_BSS|SYMTYPE_ABS
+	SYMTYPE_TEXT = 1,
+	SYMTYPE_WEAK = 2,
+	SYMTYPE_CODE = (SYMTYPE_TEXT|SYMTYPE_WEAK),
+	/* other types get sorted after code types */
+	SYMTYPE_DATA = 4,
+	SYMTYPE_BSS  = 8,
+	SYMTYPE_ABS  = 16,
+	SYMTYPE_ALL  = 32-1
 } symtype_t;
 
+typedef struct {
+	char *name;
+	uint32_t address;
+	symtype_t type;
+	bool name_allocated;
+} symbol_t;
+
 extern const char Symbols_Description[];
 
 /* readline completion support functions for CPU */
@@ -27,16 +37,16 @@ extern char* Symbols_MatchDspAddress(const char *text, int state);
 extern char* Symbols_MatchDspCodeAddress(const char *text, int state);
 extern char* Symbols_MatchDspDataAddress(const char *text, int state);
 /* symbol name -> address search */
-extern bool Symbols_GetCpuAddress(symtype_t symtype, const char *name, Uint32 *addr);
-extern bool Symbols_GetDspAddress(symtype_t symtype, const char *name, Uint32 *addr);
+extern bool Symbols_GetCpuAddress(symtype_t symtype, const char *name, uint32_t *addr);
+extern bool Symbols_GetDspAddress(symtype_t symtype, const char *name, uint32_t *addr);
 /* symbol address -> name search */
-extern const char* Symbols_GetByCpuAddress(Uint32 addr, symtype_t symtype);
-extern const char* Symbols_GetByDspAddress(Uint32 addr, symtype_t symtype);
-extern const char* Symbols_GetBeforeCpuAddress(Uint32 *addr);
-extern const char* Symbols_GetBeforeDspAddress(Uint32 *addr);
+extern const char* Symbols_GetByCpuAddress(uint32_t addr, symtype_t symtype);
+extern const char* Symbols_GetByDspAddress(uint32_t addr, symtype_t symtype);
+extern const char* Symbols_GetBeforeCpuAddress(uint32_t *addr);
+extern const char* Symbols_GetBeforeDspAddress(uint32_t *addr);
 /* TEXT symbol address -> index */
-extern int Symbols_GetCpuCodeIndex(Uint32 addr);
-extern int Symbols_GetDspCodeIndex(Uint32 addr);
+extern int Symbols_GetCpuCodeIndex(uint32_t addr);
+extern int Symbols_GetDspCodeIndex(uint32_t addr);
 /* how many TEXT symbols are loaded */
 extern int Symbols_CpuCodeCount(void);
 extern int Symbols_DspCodeCount(void);
@@ -45,6 +55,7 @@ extern void Symbols_RemoveCurrentProgram(void);
 extern void Symbols_ChangeCurrentProgram(const char *path);
 extern void Symbols_ShowCurrentProgramPath(FILE *fp);
 extern void Symbols_LoadCurrentProgram(void);
+extern void Symbols_FreeAll(void);
 /* symbols/dspsymbols command parsing */
 extern char *Symbols_MatchCommand(const char *text, int state);
 extern int Symbols_Command(int nArgc, char *psArgs[]);
