@@ -36,18 +36,13 @@
 /*--- the DSP core itself ---*/
 dsp_core_t dsp_core;
 
-/*--- Defines ---*/
-#ifndef M_PI
-#define M_PI	3.141592653589793238462643383279502
-#endif
-
 /*--- Functions prototypes ---*/
 static void dsp_core_dsp2host(void);
 static void dsp_core_host2dsp(void);
 
 static void (*dsp_host_interrupt)(int set);   /* Function to trigger host interrupt */
 
-static Uint32 const x_rom[0x100] = {
+static uint32_t const x_rom[0x100] = {
 	/* mulaw table */
 	/* M_00 */ 0x7D7C00, /* 8031 */
 	/* M_01 */ 0x797C00, /* 7775 */
@@ -310,7 +305,7 @@ static Uint32 const x_rom[0x100] = {
 };
 
 /* sin table */
-static Uint32 const y_rom[0x100] = {
+static uint32_t const y_rom[0x100] = {
 	/* S_00 */ 0x000000, /* +0.0000000000 */
 	/* S_01 */ 0x03242b, /* +0.0245412588 */
 	/* S_02 */ 0x0647d9, /* +0.0490676165 */
@@ -628,13 +623,6 @@ void dsp_core_reset(void)
 	dsp_core.periph[DSP_SPACE_X][DSP_HOST_HSR]=(1<<DSP_HOST_HSR_HTDE);
 	dsp_set_interrupt(DSP_INTER_HOST_TRX_DATA, 1);
 
-
-	/* host port init, dsp side */
-	dsp_core.periph[DSP_SPACE_X][DSP_HOST_HSR]=(1<<DSP_HOST_HSR_HTDE);
-
-	/* host port init, hreq */
-	dsp_host_interrupt(0);
-
 	/* host port init, cpu side */
 	dsp_core.hostport[CPU_HOST_ICR] = 0x0;
 	dsp_core.hostport[CPU_HOST_CVR] = 0x12;
@@ -642,6 +630,9 @@ void dsp_core_reset(void)
 	dsp_core.hostport[CPU_HOST_IVR] = 0x0f;
 	dsp_core.hostport[CPU_HOST_RX0] = 0x0;
 
+	/* host port init, hreq */
+	dsp_host_interrupt(0);
+
 	/* SSI registers */
 	dsp_core.periph[DSP_SPACE_X][DSP_SSI_SR]=1<<DSP_SSI_SR_TDE;
 	dsp_core.ssi.waitFrameTX = 1;
@@ -668,7 +659,7 @@ void dsp_core_reset(void)
 */
 
 /* Set PortC data register : send a frame order to the DMA in handshake mode */
-void dsp_core_setPortCDataRegister(Uint32 value)
+void dsp_core_setPortCDataRegister(uint32_t value)
 {
 	/* if DSP Record is in handshake mode with DMA Play */
 	if ((dsp_core.periph[DSP_SPACE_X][DSP_PCDDR] & 0x10) == 0x10) {
@@ -696,7 +687,7 @@ void dsp_core_setPortCDataRegister(Uint32 value)
 }
 
 /* SSI set TX register */
-void dsp_core_ssi_writeTX(Uint32 value)
+void dsp_core_ssi_writeTX(uint32_t value)
 {
 	/* Clear SSI TDE bit */
 	dsp_core.periph[DSP_SPACE_X][DSP_SSI_SR] &= 0xff-(1<<DSP_SSI_SR_TDE);
@@ -724,7 +715,7 @@ void dsp_core_ssi_writeTSR(void)
 }
 
 /* SSI get RX register */
-Uint32 dsp_core_ssi_readRX(void)
+uint32_t dsp_core_ssi_readRX(void)
 {
 	/* Clear SSI RDF bit */
 	dsp_core.periph[DSP_SPACE_X][DSP_SSI_SR] &= 0xff-(1<<DSP_SSI_SR_RDF);
@@ -742,7 +733,7 @@ Uint32 dsp_core_ssi_readRX(void)
  */
 void dsp_core_ssi_Receive_SC0(void)
 {
-	Uint32 value, i, temp=0;
+	uint32_t value, i, temp=0;
 
 	/* Receive data from crossbar to SSI */
 	value = dsp_core.ssi.received_value;
@@ -786,7 +777,7 @@ void dsp_core_ssi_Receive_SC0(void)
  *     value = 1 : beginning of a new frame
  *     value = 0 : not beginning of a new frame
  */
-void dsp_core_ssi_Receive_SC1(Uint32 value)
+void dsp_core_ssi_Receive_SC1(uint32_t value)
 {
 	/* SSI runs in network mode ? */
 	if (dsp_core.ssi.crb_mode) {
@@ -810,7 +801,7 @@ void dsp_core_ssi_Receive_SC1(Uint32 value)
  *     value = 1 : beginning of a new frame
  *     value = 0 : not beginning of a new frame
  */
-void dsp_core_ssi_Receive_SC2(Uint32 value)
+void dsp_core_ssi_Receive_SC2(uint32_t value)
 {
 	/* SSI runs in network mode ? */
 	if (dsp_core.ssi.crb_mode) {
@@ -835,7 +826,7 @@ void dsp_core_ssi_Receive_SC2(Uint32 value)
  */
 void dsp_core_ssi_Receive_SCK(void)
 {
-	Uint32 value, i, temp=0;
+	uint32_t value, i, temp=0;
 
 	value = dsp_core.ssi.TX;
 
@@ -877,9 +868,9 @@ void dsp_core_ssi_Receive_SCK(void)
 
 
 /* SSI initialisations and state management */
-void dsp_core_ssi_configure(Uint32 address, Uint32 value)
+void dsp_core_ssi_configure(uint32_t address, uint32_t value)
 {
-	Uint32 crb_te, crb_re;
+	uint32_t crb_te, crb_re;
 
 	switch (address) {
 		case DSP_SSI_CRA:
@@ -1047,9 +1038,9 @@ void dsp_core_hostport_dspwrite(void)
 }
 
 /* Read/writes on host port */
-Uint8 dsp_core_read_host(int addr)
+uint8_t dsp_core_read_host(int addr)
 {
-	Uint8 value;
+	uint8_t value;
 
 	value = dsp_core.hostport[addr];
 	if (addr == CPU_HOST_TRXL) {
@@ -1063,7 +1054,7 @@ Uint8 dsp_core_read_host(int addr)
 	return value;
 }
 
-void dsp_core_write_host(int addr, Uint8 value)
+void dsp_core_write_host(int addr, uint8_t value)
 {
 	switch(addr) {
 		case CPU_HOST_ICR:
@@ -1071,6 +1062,27 @@ void dsp_core_write_host(int addr, Uint8 value)
 			/* Set HF1 and HF0 accordingly on the host side */
 			dsp_core.periph[DSP_SPACE_X][DSP_HOST_HSR] &= 0xff-((1<<DSP_HOST_HSR_HF1)|(1<<DSP_HOST_HSR_HF0));
 			dsp_core.periph[DSP_SPACE_X][DSP_HOST_HSR] |= dsp_core.hostport[CPU_HOST_ICR] & ((1<<DSP_HOST_HSR_HF1)|(1<<DSP_HOST_HSR_HF0));
+			/* If requested, initialize host interface */
+			if (dsp_core.hostport[CPU_HOST_ICR] & (1<<CPU_HOST_ICR_INIT)) {
+				if (dsp_core.hostport[CPU_HOST_ICR] & (1<<CPU_HOST_ICR_RREQ)) {
+					dsp_core.hostport[CPU_HOST_ISR] &= ~(1<<CPU_HOST_ISR_RXDF);
+					dsp_core.periph[DSP_SPACE_X][DSP_HOST_HSR] |= (1<<DSP_HOST_HSR_HTDE);
+					dsp_set_interrupt(DSP_INTER_HOST_TRX_DATA, 1);
+				}
+				if (dsp_core.hostport[CPU_HOST_ICR] & (1<<CPU_HOST_ICR_TREQ)) {
+					dsp_core.hostport[CPU_HOST_ISR] |= (1<<CPU_HOST_ISR_TXDE);
+					dsp_core.periph[DSP_SPACE_X][DSP_HOST_HSR] &= ~(1<<DSP_HOST_HSR_HRDF);
+					dsp_set_interrupt(DSP_INTER_HOST_RCV_DATA, 0);
+				}
+				dsp_core.hostport[CPU_HOST_ICR] &= ~(1<<CPU_HOST_ICR_INIT);
+			}
+			/* This stops the bootstrap loader and starts normal execution */
+			if (!dsp_core.running && (dsp_core.hostport[CPU_HOST_ICR] & (1<<CPU_HOST_ICR_HF0))) {
+				LOG_TRACE(TRACE_DSP_STATE, "Dsp: stop waiting bootstrap\n");
+				dsp_core.registers[DSP_REG_R0] = dsp_core.bootstrap_pos;
+				dsp_core.registers[DSP_REG_OMR] = 0x02;
+				dsp_core.running = 1;
+			}
 			dsp_core_hostport_update_hreq();
 			break;
 		case CPU_HOST_CVR:
@@ -1117,6 +1129,8 @@ void dsp_core_write_host(int addr, Uint8 value)
 
 				if (++dsp_core.bootstrap_pos == 0x200) {
 					LOG_TRACE(TRACE_DSP_STATE, "Dsp: wait bootstrap done\n");
+					dsp_core.registers[DSP_REG_R0] = dsp_core.bootstrap_pos;
+					dsp_core.registers[DSP_REG_OMR] = 0x02;
 					dsp_core.running = 1;
 				}
 			} else {
@@ -1131,6 +1145,7 @@ void dsp_core_write_host(int addr, Uint8 value)
 
 					/* Set HRDF bit to say that DSP can read */
 					dsp_core.periph[DSP_SPACE_X][DSP_HOST_HSR] |= 1<<DSP_HOST_HSR_HRDF;
+					dsp_set_interrupt(DSP_INTER_HOST_RCV_DATA, 1);
 
 					LOG_TRACE(TRACE_DSP_HOST_INTERFACE, "Dsp: (Host->DSP): Dsp HRDF set\n");
 				}
