@@ -130,8 +130,7 @@ void Videl_Init(void)
 void VIDEL_reset(void)
 {
 	Videl_Init();
-	Screen_SetGenConvSize(videl.save_scrWidth, videl.save_scrHeight,
-	                      ConfigureParams.Screen.nForceBpp, false);
+	Screen_SetGenConvSize(videl.save_scrWidth, videl.save_scrHeight, false);
 
 	videl.bUseSTShifter = false;				/* Use Falcon color palette by default */
 	videl.reg_ffff8006_save = IoMem_ReadByte(0xff8006);
@@ -142,9 +141,6 @@ void VIDEL_reset(void)
 	/* Reset IO register (some are not initialized by TOS) */
 	IoMem_WriteWord(0xff820e, 0);    /* Line offset */
 	IoMem_WriteWord(0xff8264, 0);    /* Horizontal scroll */
-
-	/* Init sync mode register */
-	VIDEL_SyncMode_WriteByte();
 }
 
 /**
@@ -162,6 +158,48 @@ void VIDEL_MemorySnapShot_Capture(bool bSave)
 		Videl_SetDefaultSavedRes();
 }
 
+
+/**
+ * Return the vertical refresh rate for the current video mode
+ * We use the following formula :
+ *   VFreq = ( HFreq / (VFT+1) ) * 2
+ * HFreq is 15625 Hz in RGB/TV mode or 31250 Hz in VGA mode (in VGA mode HFreq can take other values in the same range)
+ *
+ * Some VFT values set by TOS :
+ *  - 320x200 16 colors, RGB : VFT = 625	-> 50 Hz
+ *  - 320x200 16 colors, VGA : VFT = 1049	-> 60 Hz
+ */
+int VIDEL_Get_VFreq(void)
+{
+	int	HFreq;
+	int	VFT;
+	int	VFreq;
+
+	if ( IoMem_ReadWord(0xff82c0) & 4 )		/* VC0 : bit2=0 32 MHz   bit2=1 25 MHz */
+		HFreq = 31250;				/* 25 MHz, VGA */
+	else
+		HFreq = 15625;				/* 32 MHz, RGB */
+
+	VFT = IoMem_ReadWord(0xff82a2);
+
+
+	VFreq = round ( ( (double)HFreq / ( VFT+1 ) ) * 2 );
+
+	return VFreq;
+}
+
+
+/**
+ * Return the content of videl.bUseSTShifter.
+ * This tells if the current video mode is compatible with ST/STE
+ * video mode or not
+ */
+bool VIDEL_Use_STShifter(void)
+{
+	return videl.bUseSTShifter;
+}
+
+
 /**
  * Monitor write access to Falcon color palette registers
  */
@@ -186,22 +224,19 @@ void VIDEL_Monitor_WriteByte(void)
 }
 
 /**
- * VIDEL_SyncMode_WriteByte : Videl synchronization mode.
- *             $FFFF820A [R/W] _______0  .................................. SYNC-MODE
-                                     ||
-                                     |+--Synchronisation [ 0:internal / 1:external ]
-                                     +---Vertical frequency [ Read-only bit ]
-                                         [ Monochrome monitor:0 / Colour monitor:1 ]
+ * VIDEL_SyncMode_WriteByte:
+ * Videl synchronization mode. Bit 1 is used by TOS 4.04 to set either 50 Hz
+ * (bit set) or 60 Hz (bit cleared).
+ * Note: There are documentation files out there that claim that bit 1 is
+ * used to distinguish between monochrome or color monitor, but these are
+ * definitely wrong.
  */
 void VIDEL_SyncMode_WriteByte(void)
 {
 	Uint8 syncMode = IoMem_ReadByte(0xff820a);
 	LOG_TRACE(TRACE_VIDEL, "Videl : $ff820a Sync Mode write: 0x%02x\n", syncMode);
 
-	if (videl.monitor_type == FALCON_MONITOR_MONO)
-		syncMode &= 0xfd;
-	else
-		syncMode |= 0x2;
+	syncMode &= 0x03;	/* Upper bits are hard-wired to 0 */
 
 	IoMem_WriteByte(0xff820a, syncMode);
 }
@@ -896,28 +931,10 @@ void VIDEL_UpdateColors(void)
 
 void Videl_ScreenModeChanged(bool bForceChange)
 {
-	int bpp;
-
-	if (ConfigureParams.Screen.nForceBpp)
-	{
-		bpp = ConfigureParams.Screen.nForceBpp;
-	}
-	else if (Avi_AreWeRecording())
-	{
-		/* Avoid changing the bpp if we are recording */
-		bpp = sdlscrn->format->BitsPerPixel;
-	}
-	else
-	{
-		/* Using SDL's 16 bpp conversion function is a bit faster */
-		bpp = (videl.save_scrBpp == 16) ? 16 : 0;
-	}
-
 	LOG_TRACE(TRACE_VIDEL, "Videl : video mode change to %dx%d@%d\n",
 	          videl.save_scrWidth, videl.save_scrHeight, videl.save_scrBpp);
 
-	Screen_SetGenConvSize(videl.save_scrWidth, videl.save_scrHeight,
-	                      bpp, bForceChange);
+	Screen_SetGenConvSize(videl.save_scrWidth, videl.save_scrHeight, bForceChange);
 }
 
 
@@ -1126,7 +1143,7 @@ void Videl_Color15_WriteWord(void)
 /**
  * display Videl registers values (for debugger info command)
  */
-void Videl_Info(FILE *fp, Uint32 dummy)
+void Videl_Info(FILE *fp, uint32_t dummy)
 {
 	if (ConfigureParams.System.nMachineType != MACHINE_FALCON) {
 		fprintf(fp, "Not Falcon - no Videl!\n");
