@@ -137,7 +137,7 @@ static int HDC_GetCount(SCSI_CTRLR *ctr)
  * Get pointer to response buffer, set up size indicator - and allocate
  * a new buffer if it is not big enough
  */
-static Uint8 *HDC_PrepRespBuf(SCSI_CTRLR *ctr, int size)
+static uint8_t *HDC_PrepRespBuf(SCSI_CTRLR *ctr, int size)
 {
 	ctr->data_len = size;
 	ctr->offset = 0;
@@ -210,7 +210,7 @@ static void HDC_Cmd_Seek(SCSI_CTRLR *ctr)
 static void HDC_Cmd_Inquiry(SCSI_CTRLR *ctr)
 {
 	SCSI_DEV *dev = &ctr->devs[ctr->target];
-	Uint8 *buf;
+	uint8_t *buf;
 	int count;
 
 	count = HDC_GetCount(ctr);
@@ -245,7 +245,7 @@ static void HDC_Cmd_RequestSense(SCSI_CTRLR *ctr)
 {
 	SCSI_DEV *dev = &ctr->devs[ctr->target];
 	int nRetLen;
-	Uint8 *retbuf;
+	uint8_t *retbuf;
 
 	nRetLen = HDC_GetCount(ctr);
 
@@ -321,7 +321,7 @@ static void HDC_Cmd_RequestSense(SCSI_CTRLR *ctr)
  * Mode sense - Vendor specific page 00h.
  * (Just enough to make the HDX tool from AHDI 5.0 happy)
  */
-static void HDC_CmdModeSense0x00(SCSI_DEV *dev, SCSI_CTRLR *ctr, Uint8 *buf)
+static void HDC_CmdModeSense0x00(SCSI_DEV *dev, SCSI_CTRLR *ctr, uint8_t *buf)
 {
 	buf[0] = 0;
 	buf[1] = 14;
@@ -349,7 +349,7 @@ static void HDC_CmdModeSense0x00(SCSI_DEV *dev, SCSI_CTRLR *ctr, Uint8 *buf)
 /**
  * Mode sense - Rigid disk geometry page (requested by ASV).
  */
-static void HDC_CmdModeSense0x04(SCSI_DEV *dev, SCSI_CTRLR *ctr, Uint8 *buf)
+static void HDC_CmdModeSense0x04(SCSI_DEV *dev, SCSI_CTRLR *ctr, uint8_t *buf)
 {
 	buf[0] = 4;
 	buf[1] = 22;
@@ -394,7 +394,7 @@ static void HDC_CmdModeSense0x04(SCSI_DEV *dev, SCSI_CTRLR *ctr, Uint8 *buf)
  */
 static void HDC_Cmd_ModeSense(SCSI_CTRLR *ctr)
 {
-	Uint8 *buf;
+	uint8_t *buf;
 	SCSI_DEV *dev = &ctr->devs[ctr->target];
 
 	LOG_TRACE(TRACE_SCSI_CMD, "HDC: MODE SENSE (%s).\n", HDC_CmdInfoStr(ctr));
@@ -462,7 +462,7 @@ static void HDC_Cmd_FormatDrive(SCSI_CTRLR *ctr)
 static void HDC_Cmd_ReportLuns(SCSI_CTRLR *ctr)
 {
 	SCSI_DEV *dev = &ctr->devs[ctr->target];
-	Uint8 *buf;
+	uint8_t *buf;
 
 	LOG_TRACE(TRACE_SCSI_CMD, "HDC: REPORT LUNS (%s).\n", HDC_CmdInfoStr(ctr));
 
@@ -488,7 +488,7 @@ static void HDC_Cmd_ReadCapacity(SCSI_CTRLR *ctr)
 {
 	SCSI_DEV *dev = &ctr->devs[ctr->target];
 	int nSectors = dev->hdSize - 1;
-	Uint8 *buf;
+	uint8_t *buf;
 
 	LOG_TRACE(TRACE_SCSI_CMD, "HDC: READ CAPACITY (%s)\n", HDC_CmdInfoStr(ctr));
 
@@ -558,7 +558,7 @@ static void HDC_Cmd_WriteSector(SCSI_CTRLR *ctr)
 static void HDC_Cmd_ReadSector(SCSI_CTRLR *ctr)
 {
 	SCSI_DEV *dev = &ctr->devs[ctr->target];
-	Uint8 *buf;
+	uint8_t *buf;
 	int n;
 
 	dev->nLastBlockAddr = HDC_GetLBA(ctr);
@@ -724,10 +724,10 @@ static void HDC_EmulateCommandPacket(SCSI_CTRLR *ctr)
  * Extended partition tables are described in AHDI release notes:
  *	https://www.dev-docs.org/docs/htm/search.php?find=AHDI
  */
-int HDC_PartitionCount(FILE *fp, const Uint64 tracelevel, int *pIsByteSwapped)
+int HDC_PartitionCount(FILE *fp, const uint64_t tracelevel, int *pIsByteSwapped)
 {
 	unsigned char *pinfo, bootsector[512];
-	Uint32 start, sectors, total = 0;
+	uint32_t start, sectors, total = 0;
 	int i, parts = 0;
 	off_t offset;
 
@@ -771,22 +771,26 @@ int HDC_PartitionCount(FILE *fp, const Uint64 tracelevel, int *pIsByteSwapped)
 	{
 		int ptype, boot;
 
-		LOG_TRACE(tracelevel, "DOS MBR:\n");
+		LOG_TRACE_DIRECT_INIT();
+		LOG_TRACE_DIRECT_LEVEL(tracelevel, "DOS MBR:\n");
 		/* first partition table entry */
 		pinfo = bootsector + 0x1BE;
 		for (i = 0; i < 4; i++, pinfo += 16)
 		{
 			boot = pinfo[0];
 			ptype = pinfo[4];
-			start = SDL_SwapLE32(*(Uint32*)(pinfo+8));
-			sectors = SDL_SwapLE32(*(Uint32*)(pinfo+12));
+			start = SDL_SwapLE32(*(uint32_t*)(pinfo+8));
+			sectors = SDL_SwapLE32(*(uint32_t*)(pinfo+12));
 			total += sectors;
-			LOG_TRACE(tracelevel, "- Partition %d: type=0x%02x, start=0x%08x, size=%.1f MB %s%s\n",
-				  i, ptype, start, sectors/2048.0, boot ? "(boot)" : "", sectors ? "" : "(invalid)");
+			LOG_TRACE_DIRECT_LEVEL(tracelevel,
+				"- Partition %d: type=0x%02x, start=0x%08x, size=%.1f MB %s%s\n",
+				i, ptype, start, sectors/2048.0, boot ? "(boot)" : "", sectors ? "" : "(invalid)");
 			if (ptype)
 				parts++;
 		}
-		LOG_TRACE(tracelevel, "- Total size: %.1f MB in %d partitions\n", total/2048.0, parts);
+		LOG_TRACE_DIRECT_LEVEL(tracelevel,
+			"- Total size: %.1f MB in %d partitions\n", total/2048.0, parts);
+		LOG_TRACE_DIRECT_FLUSH();
 	}
 	else
 	{
@@ -800,7 +804,8 @@ int HDC_PartitionCount(FILE *fp, const Uint64 tracelevel, int *pIsByteSwapped)
 		int j, flags;
 		bool extended;
 
-		LOG_TRACE(tracelevel, "ATARI MBR:\n");
+		LOG_TRACE_DIRECT_INIT();
+		LOG_TRACE_DIRECT_LEVEL(tracelevel, "ATARI MBR:\n");
 		pinfo = bootsector + 0x1C6;
 		for (i = 0; i < 4; i++, pinfo += 12)
 		{
@@ -816,7 +821,7 @@ int HDC_PartitionCount(FILE *fp, const Uint64 tracelevel, int *pIsByteSwapped)
 			extended = strcmp("XGM", pid) == 0;
 			start = HDC_ReadInt32(pinfo, 4);
 			sectors = HDC_ReadInt32(pinfo, 8);
-			LOG_TRACE(tracelevel,
+			LOG_TRACE_DIRECT_LEVEL(tracelevel,
 				  "- Partition %d: ID=%s, start=0x%08x, size=%.1f MB, flags=0x%x %s%s\n",
 				  i, pid, start, sectors/2048.0, flags,
 				  (flags & 0x80) ? "(boot)": "",
@@ -825,7 +830,9 @@ int HDC_PartitionCount(FILE *fp, const Uint64 tracelevel, int *pIsByteSwapped)
 				parts++;
 		}
 		total = HDC_ReadInt32(bootsector, 0x1C2);
-		LOG_TRACE(tracelevel, "- Total size: %.1f MB in %d partitions\n", total/2048.0, parts);
+		LOG_TRACE_DIRECT_LEVEL(tracelevel,
+			"- Total size: %.1f MB in %d partitions\n", total/2048.0, parts);
+		LOG_TRACE_DIRECT_FLUSH();
 	}
 
 	if (fseeko(fp, offset, SEEK_SET) != 0)
@@ -997,7 +1004,7 @@ void HDC_ResetCommandStatus(void)
  * Process HDC command packets (SCSI/ACSI) bytes.
  * @return true if command has been executed.
  */
-bool HDC_WriteCommandPacket(SCSI_CTRLR *ctr, Uint8 b)
+bool HDC_WriteCommandPacket(SCSI_CTRLR *ctr, uint8_t b)
 {
 	bool bDidCmd = false;
 	SCSI_DEV *dev = &ctr->devs[ctr->target];
@@ -1074,8 +1081,8 @@ bool HDC_WriteCommandPacket(SCSI_CTRLR *ctr, Uint8 b)
 
 static void Acsi_DmaTransfer(void)
 {
-	Uint32 nDmaAddr = FDC_GetDMAAddress();
-	Uint16 nDmaMode = FDC_DMA_GetMode();
+	uint32_t nDmaAddr = FDC_GetDMAAddress();
+	uint16_t nDmaMode = FDC_DMA_GetMode();
 
 	/* Don't do anything if no DMA to ACSI bus or nothing to transfer */
 	if ((nDmaMode & 0xc0) != 0x00 || AcsiBus.data_len == 0)
@@ -1123,7 +1130,7 @@ static void Acsi_DmaTransfer(void)
 	FDC_SetIRQ(FDC_IRQ_SOURCE_HDC);
 }
 
-static void Acsi_WriteCommandByte(int addr, Uint8 byte)
+static void Acsi_WriteCommandByte(int addr, uint8_t byte)
 {
 	/* Clear IRQ initially (will be set again if byte has been accepted) */
 	FDC_ClearHdcIRQ();
@@ -1169,7 +1176,7 @@ static void Acsi_WriteCommandByte(int addr, Uint8 byte)
  * Called when command bytes have been written to $FFFF8606 and
  * the HDC (not the FDC) is selected.
  */
-void HDC_WriteCommandByte(int addr, Uint8 byte)
+void HDC_WriteCommandByte(int addr, uint8_t byte)
 {
 	// fprintf(stderr, "HDC: Write cmd byte addr=%i, byte=%02x\n", addr, byte);
 
@@ -1184,7 +1191,7 @@ void HDC_WriteCommandByte(int addr, Uint8 byte)
  */
 short int HDC_ReadCommandByte(int addr)
 {
-	Uint16 ret;
+	uint16_t ret;
 	if (Config_IsMachineFalcon())
 		ret = Ncr5380_ReadByte(addr);
 	else
