@@ -79,56 +79,56 @@
 
 typedef struct {
 	/* MFP 68901 internal registers */
-	Uint8	GPIP;					/* General Purpose Pins / GPDR 0x01 */
-	Uint8	AER;					/* Active Edge Register 0x03*/
-	Uint8	DDR;					/* Data Direction Register */
-	Uint8	IERA;					/* Interrupt Enable Register A 0x07 */
-	Uint8	IERB;					/* Interrupt Enable Register B 0x09 */
-	Uint8	IPRA;					/* Interrupt Pending Register A 0x0B */
-	Uint8	IPRB;					/* Interrupt Pending Register B 0x0D */
-	Uint8	ISRA;					/* Interrupt In-Service Register A 0x0F */
-	Uint8	ISRB;					/* Interrupt In-Service Register B 0x11 */
-	Uint8	IMRA;					/* Interrupt Mask Register A 0x13 */
-	Uint8	IMRB;					/* Interrupt Mask Register B 0x15 */
-	Uint8	VR;					/* Vector Register 0x17 */
-	Uint8	TACR;					/* Timer A Control Register 0x19 */
-	Uint8	TBCR;					/* Timer B Control Register 0x1B */
-	Uint8	TCDCR;					/* Timer C/D Control Register 0x1D */
-	Uint8	TADR;					/* Timer A Data Register 0x1F */
-	Uint8	TBDR;					/* Timer B Data Register 0x21 */
-	Uint8	TCDR;					/* Timer C Data Register 0x23 */
-	Uint8	TDDR;					/* Timer D Data Register 0x25 */
-	Uint8	SCR;					/* Synchronous Data Register 0x27 */
-	Uint8	UCR;					/* USART Control Register 0x29 */
-	Uint8	RSR;					/* Receiver Status Register 0x2B */
-	Uint8	TSR;					/* Transmitter Status Register 0x2D */
-	Uint8	UDR;					/* USART Data Register 0x2F */
+	uint8_t	GPIP;					/* General Purpose Pins / GPDR 0x01 */
+	uint8_t	AER;					/* Active Edge Register 0x03*/
+	uint8_t	DDR;					/* Data Direction Register */
+	uint8_t	IERA;					/* Interrupt Enable Register A 0x07 */
+	uint8_t	IERB;					/* Interrupt Enable Register B 0x09 */
+	uint8_t	IPRA;					/* Interrupt Pending Register A 0x0B */
+	uint8_t	IPRB;					/* Interrupt Pending Register B 0x0D */
+	uint8_t	ISRA;					/* Interrupt In-Service Register A 0x0F */
+	uint8_t	ISRB;					/* Interrupt In-Service Register B 0x11 */
+	uint8_t	IMRA;					/* Interrupt Mask Register A 0x13 */
+	uint8_t	IMRB;					/* Interrupt Mask Register B 0x15 */
+	uint8_t	VR;					/* Vector Register 0x17 */
+	uint8_t	TACR;					/* Timer A Control Register 0x19 */
+	uint8_t	TBCR;					/* Timer B Control Register 0x1B */
+	uint8_t	TCDCR;					/* Timer C/D Control Register 0x1D */
+	uint8_t	TADR;					/* Timer A Data Register 0x1F */
+	uint8_t	TBDR;					/* Timer B Data Register 0x21 */
+	uint8_t	TCDR;					/* Timer C Data Register 0x23 */
+	uint8_t	TDDR;					/* Timer D Data Register 0x25 */
+	uint8_t	SCR;					/* Synchronous Data Register 0x27 */
+	uint8_t	UCR;					/* USART Control Register 0x29 */
+	uint8_t	RSR;					/* Receiver Status Register 0x2B */
+	uint8_t	TSR;					/* Transmitter Status Register 0x2D */
+	uint8_t	UDR;					/* USART Data Register 0x2F */
 
-	Uint8	IRQ;					/* IRQ signal (output) 1=IRQ requested*/
-	Uint8	TAI;					/* Input signal on Timer A (for event count mode) */
-	Uint8	TBI;					/* Input signal on Timer B (for event count mode) */
+	uint8_t	IRQ;					/* IRQ signal (output) 1=IRQ requested*/
+	uint8_t	TAI;					/* Input signal on Timer A (for event count mode) */
+	uint8_t	TBI;					/* Input signal on Timer B (for event count mode) */
 
 	/* Emulation variables */
-	Uint8 TA_MAINCOUNTER;
-	Uint8 TB_MAINCOUNTER;
-	Uint8 TC_MAINCOUNTER;
-	Uint8 TD_MAINCOUNTER;
+	uint8_t TA_MAINCOUNTER;
+	uint8_t TB_MAINCOUNTER;
+	uint8_t TC_MAINCOUNTER;
+	uint8_t TD_MAINCOUNTER;
 
 	// TODO drop those 4 variables, as they are not really used in MFP_ReadTimer_xx
-	Uint32 TimerAClockCycles;
-	Uint32 TimerBClockCycles;
-	Uint32 TimerCClockCycles;
-	Uint32 TimerDClockCycles;
+	uint32_t TimerAClockCycles;
+	uint32_t TimerBClockCycles;
+	uint32_t TimerCClockCycles;
+	uint32_t TimerDClockCycles;
 
-	Uint8	PatchTimerD_Done;			/* 0=false 1=true */
-	Uint8	PatchTimerD_TDDR_old;			/* Value of TDDR before forcing it to PATCH_TIMER_TDDR_FAKE */
+	uint8_t	PatchTimerD_Done;			/* 0=false 1=true */
+	uint8_t	PatchTimerD_TDDR_old;			/* Value of TDDR before forcing it to PATCH_TIMER_TDDR_FAKE */
 
-	Sint16	Current_Interrupt;
-	Uint64	IRQ_Time;				/* Time when IRQ was set to 1 */
-	Uint8	IRQ_CPU;				/* Value of IRQ as seen by the CPU. There's a 4 cycle delay */
+	int16_t	Current_Interrupt;
+	uint64_t	IRQ_Time;				/* Time when IRQ was set to 1 */
+	uint8_t	IRQ_CPU;				/* Value of IRQ as seen by the CPU. There's a 4 cycle delay */
 							/* between a change of IRQ and its visibility at the CPU side */
-	Uint64	Pending_Time_Min;			/* Clock value of the oldest pending int since last MFP_UpdateIRQ() */
-	Uint64	Pending_Time[ MFP_INT_MAX+1 ];		/* Clock value when pending is set to 1 for each non-masked int */
+	uint64_t	Pending_Time_Min;			/* Clock value of the oldest pending int since last MFP_UpdateIRQ() */
+	uint64_t	Pending_Time[ MFP_INT_MAX+1 ];		/* Clock value when pending is set to 1 for each non-masked int */
 
 	/* Other variables */
 	char		NameSuffix[ 10 ];		/* "" or "_tt" */
@@ -152,15 +152,15 @@ extern void	MFP_Init ( MFP_STRUCT *pAllMFP );
 extern void	MFP_Reset_All ( void );
 extern void	MFP_MemorySnapShot_Capture ( bool bSave );
 
-extern Uint8	MFP_GetIRQ_CPU ( void );
+extern uint8_t	MFP_GetIRQ_CPU ( void );
 extern void	MFP_DelayIRQ ( void );
 extern int	MFP_ProcessIACK ( int OldVecNr );
 extern bool	MFP_ProcessIRQ_All ( void );
-extern void	MFP_UpdateIRQ_All ( Uint64 Event_Time );
+extern void	MFP_UpdateIRQ_All ( uint64_t Event_Time );
 extern void	MFP_InputOnChannel ( MFP_STRUCT *pMFP , int Interrupt , int Interrupt_Delayed_Cycles );
-extern void	MFP_GPIP_Set_Line_Input ( MFP_STRUCT *pMFP , Uint8 LineNr , Uint8 Bit );
+extern void	MFP_GPIP_Set_Line_Input ( MFP_STRUCT *pMFP , uint8_t LineNr , uint8_t Bit );
 
-extern void	MFP_TimerA_Set_Line_Input ( MFP_STRUCT *pMFP , Uint8 Bit );
+extern void	MFP_TimerA_Set_Line_Input ( MFP_STRUCT *pMFP , uint8_t Bit );
 extern void	MFP_TimerA_EventCount( MFP_STRUCT *pMFP );
 extern void	MFP_TimerB_EventCount( MFP_STRUCT *pMFP , int Delayed_Cycles );
 
@@ -213,6 +213,6 @@ extern void	MFP_TimerBData_WriteByte ( void );
 extern void	MFP_TimerCData_WriteByte ( void );
 extern void	MFP_TimerDData_WriteByte ( void );
 
-extern void	MFP_Info(FILE *fp, Uint32 dummy);
+extern void	MFP_Info(FILE *fp, uint32_t dummy);
 
 #endif
