@@ -20,7 +20,18 @@ extern void Midi_Data_WriteByte(void);
 extern void Midi_InterruptHandler_Update(void);
 
 #ifdef HAVE_PORTMIDI
-extern const char* Midi_Host_GetPortName(const char *name, int offset, bool forInput);
+typedef enum {
+	MIDI_FOR_INPUT,
+	MIDI_FOR_OUTPUT
+} midi_dir_t;
+
+typedef enum {
+	MIDI_NAME_PREV = -1,
+	MIDI_NAME_FIND = 0,
+	MIDI_NAME_NEXT = +1
+} midi_name_offset_t;
+
+extern const char* Midi_Host_GetPortName(const char *name, midi_name_offset_t offset, midi_dir_t dir);
 #endif
 
 #endif
