@@ -10,6 +10,7 @@
 #ifndef HATARI_RTC_H
 #define HATARI_RTC_H
 
+extern void Rtc_Init(void);
 extern void Rtc_SecondsUnits_ReadByte(void);
 extern void Rtc_SecondsTens_ReadByte(void);
 extern void Rtc_MinutesUnits_ReadByte(void);
@@ -27,6 +28,6 @@ extern void Rtc_YearUnits_ReadByte(void);
 extern void Rtc_YearTens_ReadByte(void);
 extern void Rtc_ClockMod_ReadByte(void);
 extern void Rtc_ClockMod_WriteByte(void);
-extern void Rtc_Info(FILE *fp, Uint32 dummy);
+extern void Rtc_Info(FILE *fp, uint32_t dummy);
 
 #endif
