@@ -6,5 +6,5 @@
 */
 
 extern bool ST_FileNameIsST(const char *pszFileName, bool bAllowGZ);
-extern Uint8 *ST_ReadDisk(int Drive, const char *pszFileName, long *pImageSize, int *pImageType);
-extern bool ST_WriteDisk(int Drive, const char *pszFileName, Uint8 *pBuffer, int ImageSize);
+extern uint8_t *ST_ReadDisk(int Drive, const char *pszFileName, long *pImageSize, int *pImageType);
+extern bool ST_WriteDisk(int Drive, const char *pszFileName, uint8_t *pBuffer, int ImageSize);
