@@ -150,11 +150,7 @@ extern int nHBL;
 extern int nStartHBL;
 extern int nEndHBL;
 extern int VerticalOverscan;
-extern Uint16 HBLPalettes[HBL_PALETTE_LINES];
-extern Uint16 *pHBLPalettes;
-extern Uint32 HBLPaletteMasks[HBL_PALETTE_MASKS];
-extern Uint32 *pHBLPaletteMasks;
-extern Uint32 VideoBase;
+extern uint32_t VideoBase;
 extern int nScreenRefreshRate;
 
 extern int nScanlinesPerFrame;
@@ -186,7 +182,7 @@ extern void	Video_InitTimings(void);
 extern void	Video_SetTimings( MACHINETYPE MachineType , VIDEOTIMINGMODE Mode );
 extern const char* Video_GetTimings_Name ( void );
 
-extern Uint8	Video_Get_MONO_Line ( void );
+extern uint8_t	Video_Get_MONO_Line ( void );
 
 extern void	Video_ConvertPosition( int FrameCycles , int *pHBL , int *pLineCycles );
 extern void	Video_GetPosition( int *pFrameCycles , int *pHBL , int *pLineCycles );
@@ -261,6 +257,6 @@ extern void Video_TTShiftMode_WriteWord(void);
 extern void Video_TTColorRegs_Write(void);
 extern void Video_TTColorRegs_STRegWrite(void);
 
-extern void Video_Info(FILE *fp, Uint32 dummy);
+extern void Video_Info(FILE *fp, uint32_t dummy);
 
 #endif  /* HATARI_VIDEO_H */
