@@ -9,7 +9,7 @@
 #define HATARI_VME_H
 
 extern void VME_SetAccess(void (**readtab)(void), void (**writetab)(void));
-extern void VME_Info(FILE *fp, Uint32 arg);
+extern void VME_Info(FILE *fp, uint32_t arg);
 extern void VME_Reset(void);
 
 #endif
