@@ -7,8 +7,10 @@
 #ifndef VS_FIX_H
 #define VS_FIX_H
 
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h> /* For getting SDK version */
+
 // Stop Visual Studio complaining
-#define _CRT_SECURE_NO_WARNINGS	/* Insecure strcpy etc. */
 #pragma warning (disable:4018)	/* signed / unsigned mismatch */
 #pragma warning (disable:4049)	/* compiler limit, end of line numbering */
 #pragma warning (disable:4101)	/* unreferenced local variable */
@@ -19,7 +21,9 @@
 #pragma warning (disable:4800)	/* Performance Warning on Conversion of bool to int */
 #pragma warning (disable:4996)	/* Unsafe functions */
 
+#ifndef NTDDI_WIN10_19H1 /* this makes compilation error in newer SDK's and obviously is not needed anymore (at least from SDK NTDDI_WIN10_19H1, but maybe even from older - not tested) */
 #undef _DEBUG	/* Visual Studio is doing some macro redefinition otherwise */
+#endif
 
 typedef unsigned short mode_t;
 
