@@ -21,9 +21,9 @@ extern bool ZIP_FileNameIsZIP(const char *pszFileName);
 extern struct dirent **ZIP_GetFilesDir(const zip_dir *files, const char *dir, int *entries);
 extern void ZIP_FreeZipDir(zip_dir *zd);
 extern zip_dir *ZIP_GetFiles(const char *pszFileName);
-extern Uint8 *ZIP_ReadDisk(int Drive, const char *pszFileName, const char *pszZipPath, long *pImageSize, int *pImageType);
+extern uint8_t *ZIP_ReadDisk(int Drive, const char *pszFileName, const char *pszZipPath, long *pImageSize, int *pImageType);
 extern bool ZIP_WriteDisk(int Drive, const char *pszFileName, unsigned char *pBuffer, int ImageSize);
-extern Uint8 *ZIP_ReadFirstFile(const char *pszFileName, long *pImageSize, const char * const ppszExts[]);
+extern uint8_t *ZIP_ReadFirstFile(const char *pszFileName, long *pImageSize, const char * const ppszExts[]);
 
 
 #endif  /* HATARI_ZIP_H */
