@@ -10,10 +10,11 @@ const char Str_fileid[] = "Hatari str.c";
 
 #include <stdio.h>
 #include <ctype.h>
+#include <errno.h>
 #include <stdbool.h>
 #include <stdlib.h>
 #include <locale.h>
-#include <SDL_types.h>
+#include <assert.h>
 #include "configuration.h"
 #include "str.h"
 
@@ -132,6 +133,40 @@ char *Str_Dup(const char *str)
 	return newstr;
 }
 
+/**
+ * Copy string from pSrc to pDest, taking the destination buffer size
+ * into account.
+ * This function is similar to strscpy() in the Linux-kernel, it
+ * is a replacement for strlcpy() (which cannot be used on untrusted
+ * source strings since it tries to find out its length). Our
+ * function here returns -E2BIG instead if the string does not
+ * fit the destination buffer.
+ */
+long Str_Copy(char *pDest, const char *pSrc, long nBufLen)
+{
+	long nCount = 0;
+
+	if (nBufLen == 0)
+		return -E2BIG;
+
+	while (nBufLen) {
+		char c;
+
+		c = pSrc[nCount];
+		pDest[nCount] = c;
+		if (!c)
+			return nCount;
+		nCount++;
+		nBufLen--;
+	}
+
+	/* Hit buffer length without finding a NUL; force NUL-termination. */
+	if (nCount > 0)
+		pDest[nCount - 1] = '\0';
+
+	return -E2BIG;
+}
+
 /**
  * truncate string at first unprintable char (e.g. newline).
  */
@@ -170,6 +205,44 @@ bool Str_IsHex(const char *str)
 }
 #endif
 
+/**
+ * Convert \e, \n, \t, \\ backslash escapes in given string to
+ * corresponding byte values, anything else as left as-is.
+ */
+void Str_UnEscape(char *s1)
+{
+	char *s2 = s1;
+	for (; *s1; s1++)
+	{
+		if (*s1 != '\\')
+		{
+			*s2++ = *s1;
+			continue;
+		}
+		s1++;
+		switch(*s1)
+		{
+		case 'e':
+			*s2++ = '\e';
+			break;
+		case 'n':
+			*s2++ = '\n';
+			break;
+		case 't':
+			*s2++ = '\t';
+			break;
+		case '\\':
+			*s2++ = '\\';
+			break;
+		default:
+			s1--;
+			*s2++ = '\\';
+		}
+	}
+	assert(s2 < s1);
+	*s2 = '\0';
+}
+
 /**
  * Convert potentially too long host filenames to 8.3 TOS filenames
  * by truncating extension and part before it, replacing invalid
@@ -441,9 +514,7 @@ void Str_AtariToHost(const char *source, char *dest, int destLen, char replaceme
 {
 	if (!ConfigureParams.HardDisk.bFilenameConversion)
 	{
-		strncpy(dest, source, destLen);
-		if (destLen > 0)
-			dest[destLen-1]= '\0';
+		Str_Copy(dest, source, destLen);
 		return;
 	}
 #if defined(WIN32) || defined(USE_LOCALE_CHARSET)
