@@ -1,6 +1,6 @@
 #!/bin/sh
 
-if [ $# -lt 1 -o "$1" = "-h" -o "$1" = "--help" ]; then
+if [ $# -lt 1 ] || [ "$1" = "-h" ] || [ "$1" = "--help" ]; then
 	echo "Usage: $0 <hatari> <testprg> ..."
 	exit 1;
 fi
@@ -19,7 +19,6 @@ if [ ! -f "$testprg" ]; then
 	exit 1;
 fi;
 
-basedir=$(dirname $0)
 testdir=$(mktemp -d)
 
 remove_temp() {
@@ -32,7 +31,7 @@ export SDL_VIDEODRIVER=dummy
 export SDL_AUDIODRIVER=dummy
 
 HOME="$testdir" $hatari --log-level error --sound off --fast-forward on \
-	--tos none --run-vbls 500 $* "$testprg" > "$testdir/out.txt" 2>&1
+	--tos none --run-vbls 500 "$@" "$testprg" > "$testdir/out.txt" 2>&1
 exitstat=$?
 if [ $exitstat -ne 0 ]; then
 	echo "Running hatari failed. Status=${exitstat}."
