@@ -577,10 +577,11 @@ szPrintToFileName = %s
 
 [RS232]
 bEnableRS232 = TRUE
-bEnableSccB = TRUE
 szInFileName =
 szOutFileName = %s
-sSccBOutFileName = %s
+EnableSccB = TRUE
+SccBInFileName =
+SccBOutFileName = %s
 
 [Midi]
 bEnableMidi = TRUE
@@ -673,7 +674,8 @@ sMidiOutFileName = %s
             signal.alarm(0)
             return fifo
         except IOError:
-            print("ERROR: FIFO open IOError!")
+            print("ERROR: FIFO file open('%s') failed" % self.fifofile)
+            print("(Hatari PortMidi support not disabled?)")
             return None
 
     def test(self, identity, testargs, memwait, testwait):
