@@ -2,7 +2,22 @@
 #
 # Hatari profile data processor
 #
-# 2013-2019 (C) Eero Tamminen, licensed under GPL v2+
+# 2013-2023 (C) Eero Tamminen, licensed under GPL v2+
+#
+# TODO:
+#
+# Current way of handling symbol conflicts while they are being
+# read, causes unnecessary symbol/address conflict resolving /
+# renames, and as result outputs way too much noise about it.
+#
+# Instead, change that to work in multiple passes:
+# 1. load all symbols regardless of conflicts
+# 2. silently remove extra symbols for same address if they:
+#    - are object/library file names, or
+#    - look like weak symbols (e.g. extra _* prefix)
+# 3. remove rest of overlapping same-address symbols with warnings
+#    (need to try whether using shorter or longer name is better)
+# 4. rename identical symbols pointing to different addresses
 #
 """
 A tool for post-processing Hatari emulator HW profiling data with
@@ -113,21 +128,24 @@ Call information filtering options:
 <list> is a comma separate list of symbol names, like this:
 	--ignore-to _int_timerc,_int_vbl
 
+If (e.g. C++) symbol names contain commas, change list separator:
+	--separator ';'
+
 These options change which calls are reported for functions, and can
 affect the shape & complexity of the graph a lot.  If you e.g. want
 to see just nodes with costs specific to -p option, use "--no-calls
 berux" option.
 
-If default --no-calls type removal doesn't remove all interrupt
-handling switches [1], give handler names to --ignore-to option.
+If default "--no-calls" type removal doesn't remove all interrupt
+handling switches [1], give handler names to "--ignore-to" option.
 In callgraphs, one can then investigate them separately using
-"no-calls '' --only <name>" options.
+"--no-calls '' --only <name>" options.
 
 [1] CPU being interrupted by an interrupt handler gets recorded as
     "a call" to that handler by the profiler, and because such "calls"
     can happen at any time, then can mess graphs badly
 
-NOTE: costs shown with -p option include costs of exception handling
+NOTE: costs shown with "-p" option include costs of exception handling
 code that interrupts the function calls.  Normally effect of this
 should be minimal, but by providing symbol addresses for interrupt
 handlers their costs will be visible in output.
@@ -139,29 +157,31 @@ Callgraph filtering options to remove nodes and edges from the graph:
 				- one parent and no children,
 				- one child and no parents, or
 				- no children nor parents
-        --no-limited		remove _all_ nodes below -l limit
-        --only-subroutines      remove non-subroutine nodes below -l limit
-	--ignore <list>         no nodes for these symbols
-	--ignore-from <list>	no arrows from these symbols
-        --only <list>           only these symbols and their callers
+	--no-limited		remove _all_ nodes below -l limit
+	--no-orphans		remove unconnected nodes
+				(regardless of their cost)
+	--only-subroutines	remove non-subroutine nodes below -l limit
+	--ignore <list>		no nodes for these symbols [2]
+	--ignore-from <list>	no arrows from these symbols [2]
+        --only <list>		only these symbols and their callers [2]
 
-Leaf and intermediate node removal options remove only nodes which
-own costs fall below limit given with the -l option.  Remember to
-give -l option with them as -l defaults to 0.0 on callgraphs!
+[2] symbol matching uses shell patterns:
+    https://docs.python.org/3/library/fnmatch.html
+
+NOTE: leaf and intermediate node removal options remove only nodes which
+own costs fall below limit given with the "--limit" option.  So remember
+specify limit with them, as it defaults to 0.0 on callgraphs!
 
 Functions which are called from everywhere (like malloc), may be good
 candidates for '--ignore' option when one wants a more readable graph.
 One can then investigate them separately with the '--only <function>'
 option.
 
-NOTE: Only directly connected symbols are compacted.  You can still
-see multiple arrows between nodes in callgraphs with --compact option
-if intermediate nodes have been removed with above options.
-
 
 Callgraph visualization options:
-	--mark <list>	  	  color nodes which names contain any
-        			  of the listed string(s) differently
+	--full-symbols		  do not shorten (C++) symbols
+	--mark <list>		  color nodes which names contain any
+				  of the listed string(s) differently
         -e, --emph-limit <limit>  percentage limit for highlighted nodes
 
 When -e limit is given, it is used for deciding which nodes to
@@ -172,13 +192,15 @@ Nodes with costs that exceed the highlight limit have red outline.
 If node's own cost exceeds the limit, it has also gray background.
 
 
-To convert dot files e.g. to SVG, use:
+To convert dot files e.g. to SVG and PDF, use:
 	dot -Tsvg graph.dot > graph.svg
+	dot -Tpdf graph.dot > graph.pdf
 
 ('dot' tool is in Graphviz package.)
 """
 from copy import deepcopy
 from bisect import bisect_right
+from fnmatch import fnmatchcase
 import getopt, os, re, sys
 
 # PC address that was undefined during profiling,
@@ -270,8 +292,8 @@ class FunctionStats:
         self.subtotal = None
         self.callflags = ()
         # calltree linkage
-        self.parent = {}
-        self.child = {}
+        self.parent = {}   # addr: Callinfo tuple
+        self.child = {}    # addr: True
 
     def is_subroutine(self):
         for flag in (CALL_SUBROUTINE, CALL_STARTUP):
@@ -282,7 +304,7 @@ class FunctionStats:
     def has_cost(self):
         "return whether function has valid data yet"
         # other values are valid only if there are instructions
-        return (self.cost[1] != 0)
+        return self.cost[1] != 0
 
     def name_for_address(self, addr):
         "if name but no address, use given address and return name, otherwise None"
@@ -322,11 +344,11 @@ class FunctionStats:
 # ---------------------------------------------------------------------
 class InstructionStats:
     "statistics on all instructions"
-    # not changeable, these are expectatations about the data fields
+    # not changeable, these are expectations about the data fields
     # in this, FunctionStats, ProfileCallers and ProfileGraph classes
-    callcount_field = 0
-    instructions_field = 1
-    cycles_field = 2
+    CALLS_FIELD  = 0
+    INSTS_FIELD  = 1 # unused
+    CYCLES_FIELD = 2
 
     def __init__(self, processor, clock, fields):
         "processor name, its speed and profile field names"
@@ -367,11 +389,11 @@ class InstructionStats:
 
     def get_time(self, cost):
         "return time (in seconds) spent by given cost item"
-        return float(cost[self.cycles_field])/self.clock
+        return float(cost[self.CYCLES_FIELD])/self.clock
 
     def get_time_call(self, cost, callitem):
         "return time (in seconds) spent by given cost item per call"
-        return float(cost[self.cycles_field])/callitem[self.callcount_field]/self.clock
+        return float(cost[self.CYCLES_FIELD])/callitem[self.CALLS_FIELD]/self.clock
 
     def sum_values(self, functions):
         "calculate totals for given functions data"
@@ -393,6 +415,7 @@ class ProfileSymbols(Output):
 
     def __init__(self):
         Output.__init__(self)
+        self.renames = 0	# total of significant renames
         self.names = None
         self.symbols = None	# (addr:symbol) dict for resolving
         self.absolute = {}	# (addr:symbol) dict of absolute symbols
@@ -410,7 +433,10 @@ class ProfileSymbols(Output):
         self.r_area = re.compile("^([^:]+):[^0]*0x([0-9a-f]+)-0x([0-9a-f]+)$")
         # symbol file format:
         # [0x]<hex> [<type>] <symbol/objectfile name>
-        self.r_symbol = re.compile("^(0x)?([a-fA-F0-9]+) ([aAbBdDrRtTvVwW]) ([$]?[-_.a-zA-Z0-9]+)$")
+        # Note: C++ symbols contain almost any chars
+        self.r_symbol = re.compile("^(0x)?([a-fA-F0-9]+) ([aAbBdDrRtTvVwW]) ([$]?[._a-zA-Z(][^$?@;]*)$")
+        # weak C++ symbols can be data members, match them to ignore
+        self.r_datasym = re.compile("^.*::[_a-zA-Z][_a-zA-Z0-9]*$")
 
     def parse_areas(self, fobj, parsed):
         "parse memory area lines from data and post-process earlier read symbols data"
@@ -439,7 +465,7 @@ class ProfileSymbols(Output):
     def get_area(self, addr):
         "return memory area name + offset (used if no symbol matches)"
         for key, value in self.areas.items():
-            if value[1] and addr >= value[0] and addr <= value[1]:
+            if value[1] and value[0] <= addr <= value[1]:
                 return (key, addr - value[0])
         return (self.default_area, addr)
 
@@ -450,22 +476,47 @@ class ProfileSymbols(Output):
             # with same name?
             if name == symbols[addr]:
                 return False
-            # prefer function names over object names
-            if name.endswith('.o'):
+            # silently drop less accurate file path symbols
+            if '/' in name or name.endswith('.o') or name.endswith('.a'):
                 aliases[name] = addr
                 return False
             oldname = symbols[addr]
+            # silently override less accurate file path symbols
+            if '/' in oldname or oldname.endswith('.o') or oldname.endswith('.a'):
+                aliases[oldname] = addr
+                return True
+            # either of the names is C/C++ symbol?
+            if (name.startswith('_') or '::' in name or ' ' in name or
+                oldname.startswith('_') or '::' in oldname or ' ' in oldname):
+                # prefer shorter names for C/C++ symbols
+                if len(name) > len(oldname):
+                    aliases[name] = addr
+                    retval = False
+                else:
+                    aliases[oldname] = addr
+                    retval = True
+            else:
+                # prefer longer names for asm symbols
+                if len(name) < len(oldname):
+                    aliases[name] = addr
+                    retval = False
+                else:
+                    aliases[oldname] = addr
+                    retval = True
+            # count and warn only of significant renames
             lendiff = abs(len(name) - len(oldname))
             minlen = min(len(name), len(oldname))
-            # don't warn about object name replacements,
-            # or adding/removing short prefix or postfix
-            if not (oldname.endswith('.o') or
-                    (lendiff < 3 and minlen > 3 and
-                     (name.endswith(oldname) or oldname.endswith(name) or
-                     name.startswith(oldname) or oldname.startswith(name)))):
-                self.warning("replacing '%s' at 0x%x with '%s'" % (oldname, addr, name))
-            # add also previous name as alias for new name
-            aliases[symbols[addr]] = addr
+            if not (
+               (lendiff < 3 and minlen > 3 and
+                (name.endswith(oldname) or oldname.endswith(name) or
+                 name.startswith(oldname) or oldname.startswith(name)))):
+                if self.verbose:
+                    if retval:
+                        self.message("0x%x: prefer '%s' over '%s'" % (addr, name, oldname))
+                    else:
+                        self.message("0x%x: prefer '%s' over '%s'" % (addr, oldname, name))
+                self.renames += 1
+            return retval
         return True
 
     def _clean_aliases(self):
@@ -476,21 +527,26 @@ class ProfileSymbols(Output):
                 if addr == self.names[name]:
                     to_remove[name] = True
                     continue
+                if not self.verbose:
+                    continue
                 self.warning("multiple addresses (0x%x & 0x%x) for symbol '%s'" % (addr, self.names[name], name))
                 if addr in self.symbols:
-                    self.warning("- 0x%x is also address for symbol '%s'" % (addr, self.symbols[addr]))
-        for name in to_remove.keys():
-            del(self.aliases[name])
+                    self.message("- 0x%x is also address for symbol '%s'" % (addr, self.symbols[addr]))
+        for name in to_remove:
+            del self.aliases[name]
 
     def parse_symbols(self, fobj, is_relative):
         "parse symbol file contents"
-        unknown = lines = 0
         if is_relative:
             symbols = self.relative
             aliases = self.rel_aliases
         else:
             symbols = self.absolute
             aliases = self.aliases
+        old_aliases = len(self.aliases)
+        old_renames = self.renames
+
+        unknown = lines = cppdata = 0
         for line in fobj.readlines():
             lines += 1
             line = line.strip()
@@ -499,14 +555,33 @@ class ProfileSymbols(Output):
             match = self.r_symbol.match(line)
             if match:
                 dummy, addr, kind, name = match.groups()
-                if kind in ('t', 'T'):
-                    addr = int(addr, 16)
-                    if self._check_symbol(addr, name, symbols, aliases):
-                        symbols[addr] = name
+                if kind not in ('t', 'T', 'W'):
+                    continue
+                if (name.startswith("typeinfo ") or
+                    name.startswith("vtable ") or
+                    name.startswith("VTT ")):
+                    # C++ meta data, could be also in text section
+                    cppdata += 1
+                    continue
+                match = self.r_datasym.match(name)
+                if match:
+                    # C++ data members
+                    cppdata += 1
+                    continue
+                addr = int(addr, 16)
+                if self._check_symbol(addr, name, symbols, aliases):
+                    symbols[addr] = name
             else:
                 self.warning("unrecognized symbol line %d:\n\t'%s'" % (lines, line))
                 unknown += 1
-        self.message("%d lines with %d code symbols/addresses parsed, %d unknown." % (lines, len(symbols), unknown))
+
+        info = (lines, len(symbols), unknown)
+        self.message("%d lines with %d code symbols/addresses parsed, %d unknown." % info)
+        info = (len(aliases) - old_aliases, self.renames - old_renames)
+        self.message("%d (new) symbols were aliased, with %d significant renames." % info)
+        if cppdata:
+            self.message("%d C++ data member symbols ignored." % cppdata)
+            
 
     def _rename_symbol(self, addr, name):
         "return symbol name, potentially renamed if there were conflicts"
@@ -514,13 +589,25 @@ class ProfileSymbols(Output):
             if addr == self.names[name]:
                 return name
             # symbol with same name already exists at another address
+            chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
+            maxid = len(chars)
             idx = 1
             while True:
-                newname = "%s_%d" % (name, idx)
+                # One cannot just blindly add random suffix to a mangled C++ symbol,
+                # so use <len><idx chars> for most mangled symbols, and
+                # ".%d" suffix for ones already using vendor extension
+                if name.startswith("__Z") and '.' not in name:
+                    if idx >= maxid**2:
+                        self.warning("giving up on '%s' rename, at least %d duplicates" % (name, maxid))
+                        return name
+                    newname = "%s2%c%c" % (name, chars[idx//maxid], chars[idx%maxid])
+                else:
+                    newname = "%s.%d" % (name, idx)
                 if newname in self.names:
                     idx += 1
                     continue
-                self.warning("renaming '%s' at 0x%x as '%s' to avoid clash with same symbol at 0x%x" % (name, addr, newname, self.names[name]))
+                if self.verbose:
+                    self.message("renaming '%s' at 0x%x as '%s' to avoid clash with same symbol at 0x%x" % (name, addr, newname, self.names[name]))
                 name = newname
                 break
         self.names[name] = addr
@@ -529,7 +616,7 @@ class ProfileSymbols(Output):
     def _combine_symbols(self):
         "combine absolute and relative symbols to single lookup"
         # renaming is done only at this point (after parsing memory areas)
-        # to avoid addresses in names dict to be messed by relative symbols
+        # to avoid addresses in names dict being messed by relative symbols
         self.names = {}
         self.symbols = {}
         self.symbols_need_sort = True
@@ -561,8 +648,9 @@ class ProfileSymbols(Output):
             # -1 used because compiler can add TEXT symbol right after end of TEXT section
             if addr < area[0] or addr-1 > area[1]:
                 self.error_exit("relative symbol '%s' address 0x%x is outside of TEXT area: 0x%x-0x%x!\nDo symbols match the profiled binary?" % (name, addr, area[0], area[1]))
-            if name in self.aliases and self.aliases[name] != addr:
-                self.warning("conflicting addresses 0x%x & 0x%x for symbol '%s'" % (addr, self.aliases[name], name))
+            if self.verbose:
+                if name in self.aliases and self.aliases[name] != addr:
+                    self.message("conflicting addresses 0x%x & 0x%x for symbol '%s'" % (addr, self.aliases[name], name))
             self.aliases[name] = addr
 
     def add_profile_symbol(self, addr, name):
@@ -762,7 +850,8 @@ class ProfileCallers(Output):
                 continue
             parent = profile[paddr]
             if pname != parent.name:
-                self.warning("overriding parsed function 0x%x name '%s' with resolved caller 0x%x name '%s'" % (parent.addr, parent.name, paddr, pname))
+                if not parent.name.endswith('.o'):
+                    self.warning("overriding parsed function 0x%x name '%s' with resolved caller 0x%x name '%s'" % (parent.addr, parent.name, paddr, pname))
                 parent.name = pname
             # link parent and child function together
             if paddr in child.parent:
@@ -800,7 +889,8 @@ class ProfileCallers(Output):
             all_ignored += ignored
             # validate non-subroutine call counts
             if ignored:
-                self.message("Ignoring %d switches to %s" % (ignored, child.name))
+                if self.verbose:
+                    self.message("Ignoring %d switches to %s" % (ignored, child.name))
                 #switches += ignored
                 child.cost[0] -= ignored
             calls = child.cost[0]
@@ -865,7 +955,7 @@ class ProfileCallgrind(Output):
         # to the caller and use that as line number,
         # instead of caller function beginning line number
         parent = profile[paddr]
-        for caddr in parent.child.keys():
+        for caddr in parent.child:
             child = profile[caddr]
             if not child.subtotal:
                 # costs missing, no sense in adding dep
@@ -928,20 +1018,20 @@ class EmulatorProfile(Output):
         # <Emulator> <processor name> profile [(info)]
         #
         self.emuinfo = None
-        self.r_info = re.compile("^.* profile \((.*)\)$")
+        self.r_info = re.compile(r"^.* profile \((.*)\)$")
         # processor clock speed
-        self.r_clock = re.compile("^Cycles/second:\t([0-9]+)$")
+        self.r_clock = re.compile(r"^Cycles/second:\t([0-9]+)$")
         # field names
-        self.r_fields = re.compile("^Field names:\t(.*)$")
+        self.r_fields = re.compile(r"^Field names:\t(.*)$")
         # processor disassembly format regexp is gotten from profile file
-        self.r_regexp = re.compile("Field regexp:\t(.*)$")
+        self.r_regexp = re.compile(r"Field regexp:\t(.*)$")
         self.r_address = None
         # memory address information is parsed by ProfileSymbols
         #
         # this class parses symbols from disassembly itself:
         # <symbol/objectfile name>: (in disassembly)
-        # _biostrap:
-        self.r_function = re.compile("^([-_.a-zA-Z0-9]+):$")
+        # Note: C++ symbols contain almost any chars
+        self.r_function = re.compile(r"^([._a-zA-Z(][^$?@;]*):$")
 
         self.stats = None		# InstructionStats instance
         self.callgrind = None		# ProfileCallgrind instance
@@ -1023,7 +1113,7 @@ class EmulatorProfile(Output):
                 function.rename(name, offset)
             # addresses must increase in profile
             oldaddr = function.addr
-            assert(oldaddr not in self.profile)
+            assert oldaddr not in self.profile
             self.stats.add_callcount(function)
             self.profile[oldaddr] = function
             if self.verbose:
@@ -1035,12 +1125,11 @@ class EmulatorProfile(Output):
         name = self.symbols.get_symbol(addr)
         if name:
             return self._change_function(function, name, addr)
-        else:
-            # as no better symbol, name it according to area where it moved to?
-            name, offset = self.symbols.get_area(addr)
-            addr -= offset
-            if self.stats.change_area(function, name, addr):
-                return self._change_function(function, name, addr)
+        # as no better symbol, name it according to area where it moved to?
+        name, offset = self.symbols.get_area(addr)
+        addr -= offset
+        if self.stats.change_area(function, name, addr):
+            return self._change_function(function, name, addr)
         return function
 
     def _parse_line(self, function, addr, counts, discontinued):
@@ -1221,7 +1310,7 @@ class ProfileSorter:
                 totals = (function.cost,)
 
             showtime = False
-            if show_info and field == stats.cycles_field:
+            if show_info and field == stats.CYCLES_FIELD:
                 showtime = True
 
             for cost in totals:
@@ -1321,8 +1410,9 @@ class ProfileStats(ProfileOutput):
         "output profile statistics"
         stats = profobj.stats
         time = stats.get_time(stats.totals)
-        self.write("\nTime spent in profile = %.5fs.\n\n" % time)
+        self.write("\nTime spent in profile = %.5fs.\n" % time)
 
+        self.write("\nProfile lines with highest costs + totals:\n")
         symbols = profobj.symbols
         items = len(stats.totals)
         for i in range(items):
@@ -1332,13 +1422,13 @@ class ProfileStats(ProfileOutput):
             name, offset = symbols.get_preceeding_symbol(addr)
             if name:
                 if offset:
-                    name = " in %s+%d" % (name, offset)
+                    name = " in %s%+d" % (name, offset)
                 else:
                     name = " in %s" % name
-            self.write("%s:\n" % stats.names[i])
+            self.write("* %s:\n" % stats.names[i])
             info = (stats.max_val[i], name, addr, stats.max_line[i])
-            self.write("- max = %d,%s at 0x%x, on line %d\n" % info)
-            self.write("- %d in total\n" % stats.totals[i])
+            self.write("  - max = %d,%s at 0x%x, on line %d\n" % info)
+            self.write("  - %d in total\n" % stats.totals[i])
 
     def do_output(self, profobj):
         "output enabled lists"
@@ -1352,6 +1442,15 @@ class ProfileStats(ProfileOutput):
 
 
 # ---------------------------------------------------------------------
+def name_fnmatch(matches, name):
+    "return True if 'name' fnmatch()es one of 'matches', False otherwise"
+    if name in matches:
+        return True
+    for pattern in matches:
+        if fnmatchcase(name, pattern):
+            return True
+    return False
+
 class ProfileGraph(ProfileOutput):
     "profile callgraph output"
 
@@ -1387,22 +1486,60 @@ label="%s";
         self.edges = None
         self.highlight = None
         self.output_enabled = False
+        # callgraph node filtering
+        self.compact = False
         self.remove_intermediate = False
         self.remove_leafs = False
         self.remove_limited = False
         self.remove_nonsubs = False
+        self.remove_orphans = False
+        self.full_symbols = False
         self.only = []
         self.mark = []
         self.ignore = []
         self.ignore_from = []
         self.emph_limit = 0
+        # for demangled (C++ etc) symbols
+        self.re_thunk = re.compile(r"(non-)?virtual ") # ...thunk to
+        self.re_clone = re.compile(r" \[clone[^]]+\]") # ...isra
+        self.re_args = re.compile(r"[^(+]+::[^(+]+(\(.+\))") # class::method(args)
+
+    def _get_short_name(self, name):
+        # not C++ or other demangled symbol
+        if self.full_symbols or not (" " in name or "::" in name):
+            return name
+
+        # remove args from method signatures
+        m = self.re_args.search(name)
+        if m:
+            name = name[:m.start(1)] + "()" + name[m.end(1):]
+
+        # shorten namespaces and template args
+        name = name.replace("anonymous namespace", "anon ns")
+        name = name.replace("unsigned ", "u")
+
+        # remove virtual / clone infos from signatures
+        for r in (self.re_thunk, self.re_clone):
+            m = r.search(name)
+            if m:
+                name = name[:m.start()] + name[m.end():]
+
+        return name
+
+    def enable_full_symbols(self):
+        "do not shorten (C++) symbols"
+        self.full_symbols = True
 
     def enable_output(self):
         "enable output"
         self.output_enabled = True
 
+    def enable_compact(self):
+        "show just single edge between nodes"
+        self.compact = True
+
     def disable_intermediate(self):
-        "disable showing nodes which have just single parent/child"
+        "disable showing nodes with just single parent & child, with single edge"
         # TODO: move leaf/intermediate handling to ProfileCallers class?
         self.remove_intermediate = True
 
@@ -1414,6 +1551,10 @@ label="%s";
         "disable showing all nodes which are below limit"
         self.remove_limited = True
 
+    def disable_orphans(self):
+        "disable showing above-limit nodes which have no connections"
+        self.remove_orphans = True
+
     def only_subroutines(self):
         "disable showing nodes that aren't above limit or subroutines"
         self.remove_nonsubs = True
@@ -1443,7 +1584,7 @@ label="%s";
         profile = self.profile
         function = profile[addr]
         if self.verbose:
-            self.message("removing leaf/intermediate node %s" % function)
+            self.message("removing node %s" % function)
         parents = list(function.parent.keys())
         children = list(function.child.keys())
        # remove it from items linking it
@@ -1479,13 +1620,13 @@ label="%s";
         self.profile = deepcopy(profobj.profile)
         total = totals[field]
         to_remove = {}
-        removed = 0
         if self.ignore:
             for addr, function in self.profile.items():
-                if function.name in self.ignore:
+                if name_fnmatch(self.ignore, function.name):
                     to_remove[addr] = True
+        removed = 0
         while True:
-            for addr in to_remove.keys():
+            for addr in to_remove:
                 self._remove_from_profile(addr)
             removed += len(to_remove)
             to_remove = {}
@@ -1494,6 +1635,14 @@ label="%s";
                 if self.remove_nonsubs and not function.is_subroutine():
                     to_remove[addr] = True
                     continue
+
+                parents = len(function.parent)
+                children = len(function.child)
+                # remove orphans regardless of their cost?
+                if self.remove_orphans and (parents + children) == 0:
+                    to_remove[addr] = True
+                    continue
+
                 # don't remove symbols which own costs are over the limit
                 if self.show_subcosts and function.subcost and len(function.subcost) > field:
                     count = function.subcost[field]
@@ -1505,9 +1654,8 @@ label="%s";
                 if self.remove_limited:
                     to_remove[addr] = True
                     continue
+
                 # remove leafs & intermediates
-                parents = len(function.parent)
-                children = len(function.child)
                 if self.remove_leafs:
                     if (parents + children) <= 1:
                         to_remove[addr] = True
@@ -1525,12 +1673,12 @@ label="%s";
                         continue
                     # refers also to itself?
                     if children == 2:
-                        for caddr in function.child.keys():
+                        for caddr in function.child:
                             if caddr == addr:
                                 to_remove[addr] = True
                                 break
                     if parents == 2:
-                        for paddr in function.parent.keys():
+                        for paddr in function.parent:
                             if paddr == addr:
                                 to_remove[addr] = True
                                 break
@@ -1543,7 +1691,6 @@ label="%s";
         profile = self.profile
         self.nodes = {}
         self.edges = {}
-        ignore_from = self.ignore_from
         for caddr, child in profile.items():
             if not child.parent:
                 self.nodes[caddr] = True
@@ -1554,26 +1701,34 @@ label="%s";
                 # if caddr == paddr:
                 #    continue
                 if self.only:
-                    if not (child.name in self.only or parent.name in self.only):
+                    if not (name_fnmatch(self.only, child.name) or
+                            name_fnmatch(self.only, parent.name)):
                         continue
                 # child end for edges
                 self.nodes[caddr] = True
-                if parent.name in ignore_from:
+                if name_fnmatch(self.ignore_from, parent.name):
                     continue
                 # parent end for edges
                 self.nodes[paddr] = True
                 # total calls count for child
                 all_calls = profile[caddr].cost[0]
-                # calls to child done from different locations in parent
-                for edge in info:
-                    self.edges[(edge.addr, caddr)] = (paddr, all_calls, edge)
-        return (len(profile) - len(self.nodes))
+                if self.compact:
+                    edge = Callinfo(paddr)
+                    # TODO: "pick first" not good enough?
+                    edge.flags = [x.flags for x in info][0]
+                    edge.calls = sum([x.calls for x in info])
+                    self.edges[(paddr, caddr)] = (paddr, all_calls, edge)
+                else:
+                    # calls to child done from different locations in parent
+                    for edge in info:
+                        self.edges[(edge.addr, caddr)] = (paddr, all_calls, edge)
+        return len(profile) - len(self.nodes)
 
     def _output_nodes(self, stats, field, limit):
         "output graph nodes from filtered nodes dict"
         self.highlight = {}
         total = stats.totals[field]
-        for addr in self.nodes.keys():
+        for addr in self.nodes:
             shape = style = ""
             function = self.profile[addr]
             calls = function.cost[0]
@@ -1595,9 +1750,8 @@ label="%s";
             ownpercentage = 100.0 * owncount / total
             if ownpercentage >= limit:
                 style = "%s style=filled fillcolor=lightgray" % style
-            name = function.name
             for substr in self.mark:
-                if substr in name:
+                if substr in function.name:
                     style = "%s style=filled fillcolor=green shape=square" % style
                     break
             if CALL_STARTUP in function.callflags:
@@ -1606,9 +1760,11 @@ label="%s";
                 coststr = "%.2f%%\\n(own: %.2f%%)" % (percentage, ownpercentage)
             else:
                 coststr = "%.2f%%" % percentage
+
+            name = self._get_short_name(function.name)
             if field == 0:
                 self.write("N_%X [label=\"%s\\n%s\\n%d calls\"%s%s];\n" % (addr, coststr, name, count, style, shape))
-            elif field == stats.cycles_field:
+            elif field == stats.CYCLES_FIELD:
                 time = stats.get_time(cost)
                 self.write("N_%X [label=\"%s\\n%.5fs\\n%s\\n(%d calls)\"%s%s];\n" % (addr, coststr, time, name, calls, style, shape))
             else:
@@ -1619,16 +1775,16 @@ label="%s";
         for linkage, info in self.edges.items():
             laddr, caddr = linkage
             paddr, calls, edge = info
-            pname = self.profile[paddr].name
             offset = laddr - paddr
             style = ""
             if caddr in self.highlight:
                 style = " color=red style=bold"
+
             # arrowhead/tail styles:
             #   none, normal, inv, dot, odot, invdot, invodot, tee, empty,
             #   invempty, open, halfopen, diamond, odiamond, box, obox, crow
             flags = edge.flags
-            if flags == CALL_NEXT or flags == CALL_BRANCH:
+            if flags in (CALL_NEXT, CALL_BRANCH):
                 style += " arrowhead=dot"
             elif flags == CALL_SUBROUTINE:
                 pass	# use default arrow
@@ -1640,8 +1796,10 @@ label="%s";
                 style += " arrowhead=inv style=dashed"
             elif flags == CALL_UNKNOWN:
                 style += " arrowhead=diamond style=dotted"
+
+            pname = self._get_short_name(self.profile[paddr].name)
             if offset:
-                label = "%s+%d\\n($%x)" % (pname, offset, laddr)
+                label = "%s%+d\\n($%x)" % (pname, offset, laddr)
             else:
                 label = pname
             if edge.calls != calls:
@@ -1704,6 +1862,7 @@ class Main(Output):
         "compact",
         "emph-limit=",
         "first",
+        "full-symbols",
         "graph",
         "ignore=",
         "ignore-to=",
@@ -1715,11 +1874,13 @@ class Main(Output):
         "no-intermediate",
         "no-leafs",
         "no-limited",
+        "no-orphans",
         "only=",
         "only-subroutines",
         "output=",
         "propagate",
         "relative=",
+        "separator=",
         "stats",
         "top",
         "verbose"
@@ -1743,22 +1904,24 @@ class Main(Output):
         prof = EmulatorProfile()
         graph = ProfileGraph()
         stats = ProfileStats()
+
+        splitter = ','
         for opt, arg in opts:
             #self.message("%s: %s" % (opt, arg))
             # options for profile symbol parsing
-            if opt in ("-a", "--absolute"):
+            if opt == "--separator":
+                splitter = arg
+            elif opt in ("-a", "--absolute"):
                 self.message("\nParsing absolute symbol address information from %s..." % arg)
                 prof.parse_symbols(self.open_file(arg, "r"), False)
             elif opt in ("-r", "--relative"):
                 self.message("\nParsing TEXT relative symbol address information from %s..." % arg)
                 prof.parse_symbols(self.open_file(arg, "r"), True)
             # options for profile caller information parsing
-            elif opt == "--compact":
-                prof.enable_compact()
             elif opt == "--no-calls":
                 prof.remove_calls(arg)
             elif opt == "--ignore-to":
-                prof.set_ignore_to(arg.split(','))
+                prof.set_ignore_to(arg.split(splitter))
             # options for profile Callgraph info generation
             elif opt in ("-k", "--callgrind"):
                 prof.enable_callgrind()
@@ -1774,25 +1937,32 @@ class Main(Output):
             elif opt in ("-p", "--propagate"):
                 graph.enable_subcosts()
                 stats.enable_subcosts()
+            elif opt == "--compact":
+                prof.enable_compact()
+                graph.enable_compact()
             # options specific to graphs
             elif opt in ("-e", "--emph-limit"):
                 graph.set_emph_limit(self.get_value(opt, arg, True))
+            elif opt == "--full-symbols":
+                graph.enable_full_symbols()
             elif opt in ("-g", "--graph"):
                 graph.enable_output()
             elif opt == "--ignore":
-                graph.set_ignore(arg.split(','))
+                graph.set_ignore(arg.split(splitter))
             elif opt == "--ignore-from":
-                graph.set_ignore_from(arg.split(','))
+                graph.set_ignore_from(arg.split(splitter))
             elif opt == "--only":
-                graph.set_only(arg.split(','))
+                graph.set_only(arg.split(splitter))
             elif opt == "--mark":
-                graph.set_marked(arg.split(','))
+                graph.set_marked(arg.split(splitter))
             elif opt == "--no-intermediate":
                 graph.disable_intermediate()
             elif opt == "--no-leafs":
                 graph.disable_leafs()
             elif opt == "--no-limited":
                 graph.disable_limited()
+            elif opt == "--no-orphans":
+                graph.disable_orphans()
             elif opt == "--only-subroutines":
                 graph.only_subroutines()
             # options specific to statistics
@@ -1827,17 +1997,16 @@ class Main(Output):
         try:
             return open(path, mode)
         except IOError as err:
-            self.usage("opening given '%s' file in mode '%s' failed:\n\t%s" % (path, mode, err))
+            return self.usage("opening given '%s' file in mode '%s' failed:\n\t%s" % (path, mode, err))
 
     def get_value(self, opt, arg, tofloat):
         "return numeric value for given string"
         try:
             if tofloat:
                 return float(arg)
-            else:
-                return int(arg)
+            return int(arg)
         except ValueError:
-            self.usage("invalid '%s' numeric value: '%s'" % (opt, arg))
+            return self.usage("invalid '%s' numeric value: '%s'" % (opt, arg))
 
     def usage(self, msg):
         "show program usage + error message"
